##This script 
## - loads the Chru acoustic data (obtained from PraatSauce) 
## - merges data from different speakers 
## - add sociolinguistic and phonological variables
## - removes tracking errors and outliers
## - normalizes data
## - plots results
## - runs statistical analyses
## - calculates Cohen d's for individual differences and plots them

## Written by Marc Brunelle, James Kirby and Ta Thanh Tan from 2018 to 2020


##Load libraries and set working directory
require(ggplot2)
require(reshape2)
require(tidyr)
require(plyr)
require(data.table)
require(lmerTest)
require(zoo)
require(optimx)
require(ggpubr)

theme_set(theme_bw())

## Change to location of acoustic measure .csv files
setwd("C:\\Users\\Owner\\Desktop\\Chru_paper\\Chru_paper_April_2020\\Data\\Acoustic_results")


##### PART I: LOAD DATA, MERGE DATA FROM DIFFERENT SPEAKERS AND ADD SOCIOLINGUISTIC AND PHONOLOGICAL VARIABLES

## Load PraatSauce data
PSfilelist = list.files(pattern = "txt$")
PSdatalist = lapply(PSfilelist, FUN=read.csv, header=TRUE)
PS = do.call("rbind", PSdatalist)

## Rename columns
colnames(PS)[1:7] <- c('Filename', 'Frontness' ,'Language', 'Subject', 'Repetition', 'Target', 'Word')

## Convert to msec
PS$seg_Start <- PS$seg_Start * 1000
PS$seg_End <- PS$seg_End * 1000
PS$ov <- PS$ov * 1000
PS$cv <- PS$cv * 1000
PS$rv <- PS$rv * 1000
PS$t_ms <- PS$t_ms * 1000

## Fix annotation errors

#Annotation typos in column Word
PS$Word <- as.character(PS$Word)
PS[PS$Word == "thwnu",]$Word <- "thwznu"
PS[PS$Word == "bwzNNi",]$Word <- "bwzNi" 
PS[PS$Word == "DDu",]$Word <- "Du" 
PS$Word <- as.factor(PS$Word)

#Annotation typos in target
PS$Target <- revalue(PS$Target, c("DDu"="Du", "NNi"="Ni", "kwdO"="dO", "NI"="Ni", "no"="nO"))

##Add sociolinguistic variables

# Create "Sex" column
PS$Sex <- as.factor(substr(PS$Subject, 1, 1))

# Create "Age" column
PS$Age <- rep(18)
PS[PS$Subject == "F13",]$Age <- 20 
PS[PS$Subject == "M9",]$Age <- 22
PS[PS$Subject%in%c("M2", "M8"),]$Age <- 24
PS[PS$Subject == "F8",]$Age <- 26
PS[PS$Subject == "M6",]$Age <- 31
PS[PS$Subject%in%c("F10","F15"),]$Age <- 33
PS[PS$Subject == "M11",]$Age <- 39
PS[PS$Subject == "F12",]$Age <- 40
PS[PS$Subject%in%c("F2", "F5"),]$Age <- 44
PS[PS$Subject == "M10",]$Age <- 49
PS[PS$Subject == "F6",]$Age <- 50
PS[PS$Subject == "F11",]$Age <- 52
PS[PS$Subject == "F3",]$Age <- 53
PS[PS$Subject == "M4",]$Age <- 56
PS[PS$Subject == "F1",]$Age <- 58
PS[PS$Subject%in%c("F4", "M12"),]$Age <- 60
PS[PS$Subject == "M7",]$Age <- 61
PS[PS$Subject == "M1",]$Age <- 63
PS[PS$Subject == "F9",]$Age <- 65
PS[PS$Subject == "M5",]$Age <- 67


##Add phonological variables

# Create Onset variable
PS$Onset <- as.factor(substring(PS$Target, 1, 2))
PS$Onset <- as.factor(gsub("[aoOuiEUIe]", "", PS$Onset))

# Create "Vowel" variable
PS$Vowel <- as.factor(substring(PS$Target, 2, 3))
PS$Vowel <- as.factor(gsub("[hlqnt]", "", PS$Vowel))

# Create "Manner" variable
PS$Manner<- rep("stop")
PS[PS$Onset == "s",]$Manner <- "fricative"
PS[PS$Onset%in%c("r", "n", "l", "N"),]$Manner <- "sonorant"
PS[PS$Onset%in%c("th", "kh"),]$Manner <- "aspirated"
PS[PS$Onset == "D",]$Manner <- "implosive"
PS$Manner <- as.factor(PS$Manner)

# Create "Place" variable
PS$Place <- rep("coronal")
PS[PS$Onset %in% c("k", "g", "kh", "N"),]$Place <- "velar"
PS$Place <- as.factor(PS$Place)

# Create "Register" variable
PS$Register <- rep("Neutral")
PS[PS$Onset %in% c("t", "k", "th", "kh"),]$Register <- "High"
PS[PS$Onset %in% c("d", "g"),]$Register <- "Low"
PS$Register <- as.factor(PS$Register)

# Assign non-contrative register to sonorants based on presyllable
PS[PS$Word %in% c("bwzNa", "bwzNE", "bwzni", "bwzNi", "bwzNNi", "dwznO", "gwzla", "gwznaN", "jwzlEn", "swzla", "swzna", "swznE", "bwzNNa"),]$Register <- "Low"
PS[PS$Word %in% c("hwzniN", "hwzNO", "hwzri", "pwzNE", "swzla", "swzna", "swznE", "thwznu", "twzli", "twzNan", "twznO", "pwNE", "hwzNo", "thwnu"),]$Register <- "High"

# Calculate VOT
PS$VOT = PS$ov - PS$seg_Start

## Since formants have to be measured separately for front and back vowels for many speakers, only keep relevant data based on a manually added "Frontness" column   
PS1 <- droplevels(subset(PS, (Vowel == "u" | Vowel == "O" | Vowel == "uo") & Frontness == "Back"))
PS2 <- droplevels(subset(PS, (Vowel != "u" & Vowel != "O" & Vowel != "uo") & Frontness == "Front"))  
PS3 <- droplevels(subset(PS, Frontness == "All"))
PS <- rbind(PS1, PS2, PS3)

# Create a category for voicers and devoicers (defined and used in Part III) 
PS$VoiGr <- "Dev"
PS[PS$Subject%in%c("F4", "M1", "M11", "M12", "M4", "M5", "M6", "M7"), ]$VoiGr <- "Voi"

## Keep one observation per open phase (here, the first one) for VOT measures
PSop1 <- droplevels(subset(PS, Label == "op" & t == "1"))

## Create dataframe for closure measurements
PSclo <- droplevels(subset(PS, Label == "fr" | Label == "cl"))

## Create dataframe that only contains the vowel (for vocalic measures) 
PSop <- droplevels(subset(PS, Label == "op" & t_ms >= ov))

## Save the three dataframes, so that this section of the script doesn't have to be run everytime 
write.csv(PSop, "PSop.csv", row.names=F)
write.csv(PSop1, "PSop1.csv", row.names=F)
write.csv(PSclo, "PSclo.csv", row.names=F)


#####	PART II: REMOVE TRACKING ERRORS AND OUTLIERS, AND NORMALIZE DATA 

## If output files of Part I are already available, start here to save time, and run the following line
#PSop <- read.csv("PSop.csv", sep = ",", dec = ".")

## Remove the first and the last 12 time points.  Since the measurement window is 25 ms wide, they include meaningless consonantal measures.  
PSop$min_t <- ave(PSop$t, PSop$Filename, FUN=min)
PSop$max_t <- ave(PSop$t, PSop$Filename, FUN=max)
PSop <- droplevels(subset(PSop, t > min_t + 11 & t < max_t - 11))
PSop$min_t <- NULL
PSop$max_t <- NULL

### Align the data so that all contours start at t=1
PSop$min_t <- ave(PSop$t, PSop$Filename, FUN=min)
PSop$corr_t <- PSop$t - PSop$min_t + 1


### CLEAN UP TRACKING ERRORS

## Start with abrupt jumps in tracking

#Initial normalization by speaker(just for clean up)
PSop <- transform(PSop, Zf0=ave(f0 ,Subject, FUN=scale))
PSop <- transform(PSop, F1Lob=ave(F1, Subject, FUN=scale))
PSop <- transform(PSop, F2Lob=ave(F2, Subject, FUN=scale))
PSop <- transform(PSop, F3Lob=ave(F3, Subject, FUN=scale))

# Get derivatives per level for f0, F1 and F2
PSop$f0der <- ave(PSop$Zf0, PSop$Filename, FUN=function(x) c(0,diff(x)))
PSop$F1der <- ave(PSop$F1Lob, PSop$Filename, FUN=function(x) c(0,diff(x)))
PSop$F2der <- ave(PSop$F2Lob, PSop$Filename, FUN=function(x) c(0,diff(x)))
PSop$F3der <- ave(PSop$F3Lob, PSop$Filename, FUN=function(x) c(0,diff(x)))

# To plot the distribution, use following line
#ggplot(data=PSop, aes(f0der)) + geom_histogram(breaks=seq(-0.25, 0.25, by=0.01)) 

# Remove tails if derivatives <-0.05 and > 0.05
PSop <- PSop %>% mutate(f0=ifelse(f0der < -0.05 | f0der > 0.05, NA, f0))
PSop <- PSop %>% mutate(F1=ifelse(F1der < -0.05 | F1der > 0.05, NA, F1))
PSop <- PSop %>% mutate(F2=ifelse(F2der < -0.05 | F2der > 0.05, NA, F2))
PSop <- PSop %>% mutate(F3=ifelse(F3der < -0.05 | F3der > 0.05, NA, F3))

# Remove 0s if they are not at corr_t == 1 (keep corr_t = 1, because the first measurement has a derivative of 0)
PSop <- PSop %>% mutate(f0=ifelse(f0der == 0 & corr_t != 1, NA, f0)) 
PSop <- PSop %>% mutate(F1=ifelse(F1der == 0 & corr_t != 1, NA, F1))
PSop <- PSop %>% mutate(F2=ifelse(F2der == 0 & corr_t != 1, NA, F2))
PSop <- PSop %>% mutate(F3=ifelse(F3der == 0 & corr_t != 1, NA, F3))


## To save provisional data, use following line
#write.csv(PSop, "PSoptemp.csv")

## Remove as many of the remaining f0 and formant tracking errors (without removing useful data) by excluding measurements that are 3 standard deviations away from the mean(per subject*vowel*register)
# The decision to use 3 standard deviations was made after inspecting the data:
# If the threshold is raised, less data is excluded, but there are more errors
# If the threshold is lowered, more data is excluded, but there are fewer errors left


PSop <- PSop %>%
  group_by(Vowel, Subject, Register) %>%
  mutate(uppf0 = mean(f0, na.rm = TRUE) + 3*sd(f0, na.rm = TRUE),
         lowf0 = mean(f0, na.rm = TRUE) - 3*sd(f0, na.rm = TRUE),
         uppF1 = mean(F1, na.rm = TRUE) + 3*sd(F1, na.rm = TRUE),
         lowF1 = mean(F1, na.rm = TRUE) - 3*sd(F1, na.rm = TRUE),
         uppF2 = mean(F2, na.rm = TRUE) + 3*sd(F2, na.rm = TRUE),
         lowF2 = mean(F2, na.rm = TRUE) - 3*sd(F2, na.rm = TRUE),
         uppF3 = mean(F3, na.rm = TRUE) + 3*sd(F3, na.rm = TRUE),
         lowF3 = mean(F3, na.rm = TRUE) - 3*sd(F3, na.rm = TRUE))

PSop <- PSop %>%
  mutate(f0 = ifelse((f0 > uppf0 | f0 < lowf0), NA, f0),
         F1 = ifelse((F1 > uppF1 | F1 < lowF1), NA, F1),
         F2 = ifelse((F2 > uppF2 | F2 < lowF2), NA, F2),
         F3 = ifelse((F3 > uppF3 | F3 < lowF3), NA, F3))

## The following lines inspect the number of NAs introduced by the preceding loop at specific time frames.
# temp <- subset(PSop, corr_t == 1)
# NAs <- ddply(temp, c("Word"), summarise, Total = length(F1), nbNA = sum(is.na(F1)))

## To save provisional data, use following line
# write.csv(PSop, "PSopint.csv")

## Remove the bandwidth and spectral slope measures that depend on the f0 and formant measures just excluded
PSop <- PSop %>% mutate(B1=ifelse(is.na(F1), NA, B1))
PSop <- PSop %>% mutate(B2=ifelse(is.na(F2), NA, B2))
PSop <- PSop %>% mutate(B3=ifelse(is.na(F3), NA, B3))
PSop <- PSop %>% mutate(H1u=ifelse(is.na(f0), NA, H1u))
PSop <- PSop %>% mutate(H2u=ifelse(is.na(f0), NA, H2u))
PSop <- PSop %>% mutate(H4u=ifelse(is.na(f0), NA, H4u))
PSop <- PSop %>% mutate(A1u=ifelse(is.na(F1), NA, A1u))
PSop <- PSop %>% mutate(A2u=ifelse(is.na(F2), NA, A2u))
PSop <- PSop %>% mutate(A3u=ifelse(is.na(F3), NA, A3u))
PSop <- PSop %>% mutate(H1H2u=ifelse(is.na(f0), NA, H1H2u))
PSop <- PSop %>% mutate(H2H4u=ifelse(is.na(f0), NA, H2H4u))
PSop <- PSop %>% mutate(H1A1u=ifelse(is.na(f0) | is.na(F1), NA, H1A1u))
PSop <- PSop %>% mutate(H1A2u=ifelse(is.na(f0) | is.na(F2), NA, H1A2u))
PSop <- PSop %>% mutate(H1A3u=ifelse(is.na(f0) | is.na(F3), NA, H1A3u))
PSop <- PSop %>% mutate(H1c=ifelse(is.na(f0), NA, H1c))
PSop <- PSop %>% mutate(H2c=ifelse(is.na(f0), NA, H2c))
PSop <- PSop %>% mutate(H4c=ifelse(is.na(f0), NA, H4c))
PSop <- PSop %>% mutate(A1c=ifelse(is.na(F1), NA, A1c))
PSop <- PSop %>% mutate(A2c=ifelse(is.na(F2), NA, A2c))
PSop <- PSop %>% mutate(A3c=ifelse(is.na(F3), NA, A3c))
PSop <- PSop %>% mutate(H1c=ifelse(is.na(f0), NA, H1c))
PSop <- PSop %>% mutate(H2c=ifelse(is.na(f0), NA, H2c))
PSop <- PSop %>% mutate(H4c=ifelse(is.na(f0), NA, H4c))
PSop <- PSop %>% mutate(A1c=ifelse(is.na(F1), NA, A1c))
PSop <- PSop %>% mutate(A2c=ifelse(is.na(F2), NA, A2c))
PSop <- PSop %>% mutate(A3c=ifelse(is.na(F3), NA, A3c))
PSop <- PSop %>% mutate(H1H2c=ifelse(is.na(f0), NA, H1H2c))
PSop <- PSop %>% mutate(H2H4c=ifelse(is.na(f0), NA, H2H4c))
PSop <- PSop %>% mutate(H1A1c=ifelse(is.na(f0) | is.na(F1), NA, H1A1c))
PSop <- PSop %>% mutate(H1A2c=ifelse(is.na(f0) | is.na(F2), NA, H1A2c))
PSop <- PSop %>% mutate(H1A3c=ifelse(is.na(f0) | is.na(F3), NA, H1A3c))

PSop <- data.frame(PSop)
PSop[71:78] <- NULL

## Proportion of tokens removed from the data
# sum(length(which(is.na(PSop$F3))))/nrow(PSop)
# f0: 2.4% of data removed 
# F1: 4.5% of data removed
# F2: 4.4% of data removed
# F3: 18.2% of data removed 
# H1H2c: 2.4% removed
# H1A2c: 6.6% removed
# H1A3c: 20% removed


###NORMALIZATION BY SPEAKER

# According to Rose 2013, z-score is the best normalization for f0
PSop <- transform(PSop, Zf0=ave(f0 ,Subject, FUN=scale))
PSop$normf0 <- mean(PSop$f0, na.rm=TRUE) + PSop$Zf0 * sd(PSop$f0, na.rm=TRUE)

PSop <- transform(PSop, ZH1H2c=ave(H1H2c, Subject, FUN=scale))
PSop <- transform(PSop, ZH2H4c=ave(H2H4c, Subject, FUN=scale))
PSop <- transform(PSop, ZH1A1c=ave(H1A1c, Subject, FUN=scale))
PSop <- transform(PSop, ZH1A2c=ave(H1A2c, Subject, FUN=scale))
PSop <- transform(PSop, ZH1A3c=ave(H1A3c, Subject, FUN=scale))
PSop <- transform(PSop, ZCPP=ave(CPP, Subject, FUN=scale))
# Recent implementation of Lobanov normalization are just z-scores, so do the same:
PSop <- transform(PSop, F1Lob=ave(F1, Subject, FUN=scale))
PSop <- transform(PSop, F2Lob=ave(F2, Subject, FUN=scale))
PSop <- transform(PSop, F3Lob=ave(F3, Subject, FUN=scale))

# Create normalized values (= intuitive variables rescaled based on overall mean and sd) 
PSop$normH1H2 <- mean(PSop$H1H2c, na.rm=TRUE) + PSop$ZH1H2c * sd(PSop$H1H2c, na.rm=TRUE)
PSop$normH1A1 <- mean(PSop$H1A1c, na.rm=TRUE) + PSop$ZH1A1c * sd(PSop$H1A1c, na.rm=TRUE)
PSop$normH1A3 <- mean(PSop$H1A3c, na.rm=TRUE) + PSop$ZH1A3c * sd(PSop$H1A3c, na.rm=TRUE)
PSop$normCPP <- mean(PSop$CPP, na.rm=TRUE) + PSop$ZCPP * sd(PSop$CPP, na.rm=TRUE)
PSop$normF1 <- mean(PSop$F1, na.rm=TRUE) + PSop$F1Lob * sd(PSop$F1, na.rm=TRUE)
PSop$normF2 <- mean(PSop$F2, na.rm=TRUE) + PSop$F2Lob * sd(PSop$F2, na.rm=TRUE)

## Save cleaned up and normalized data
write.csv(PSop, "PSopfinal.csv")


#####	PART III: PLOTS AND ASSOCIATED STATS

## If starting here, load the data files 
# PSop <- read.csv("PSopfinal.csv")
# PSop1 <- read.csv("PSop1.csv")
# PSclo <- read.csv("PSclo.csv")

###CONSONANT CHARTS AND STATS

## VOT per stop type (Fig. 3)
stopVOT <- droplevels(subset(PSop1, (Manner == "stop" | Manner == "implosive" | Manner == "aspirated") & VOT < 200 & VOT > -200))
stopVOT$Register2 <- rep("No contrast")
stopVOT[stopVOT$Register == "Low",]$Register2 <- "Low"
stopVOT[stopVOT$Register == "High" & stopVOT$Manner != "aspirated",]$Register2 <- "High"
# Remove "Du" when it is realized with a positive VOT as diN kEj Du is often inaccurately realized as du with a plain voiced stop rather than an implosive
stopVOT <- droplevels(subset(stopVOT, Target != "Du" | VOT < 0))
stopVOT$Manner <- factor(stopVOT$Manner,levels(stopVOT$Manner)[c(2,1,3)])
stopVOT$Register2 <- as.factor(stopVOT$Register2)
stopVOT$Register2 <- factor(stopVOT$Register2,levels(stopVOT$Register2)[c(2,1,3)])
VOTplot <- ggplot(stopVOT, aes(x=VOT, fill=Manner)) + geom_histogram(alpha = 0.6, position="identity", binwidth =10) + facet_grid(Register2~Place, scales = "free")
VOTplot <- VOTplot + theme(legend.position="bottom", text = element_text(size=10),axis.text.x = element_text(angle=90)) + labs(x = "VOT (ms)")
VOTplot

bmp("Fig 3 VOT.bmp", units="cm", width=10, height=10, res=600)
VOTplot
dev.off()

## Difference between VOT of high-register and devoiced low-register stops (Table 1 Appendix B) 
posVOT <- droplevels(subset(stopVOT, VOT >= 0 & Manner == "stop"))
# Here, too few observations to include random slopes
posVOT.lmer <- lmer(VOT~Register*Place+Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),posVOT)
# Removal of Register*Vowel makes AIC significantly higher, so stop here

# Save model if needed
save(posVOT.lmer, file = "Positive VOT in stops.RData")
write.csv(summary(posVOT.lmer)$coefficients, "posVOTfinalmodel.csv")


## Proportion of voiced stops with closure voicing (Fig. 4)
LowRegStops <- droplevels(subset(PSop1, Manner == "stop" & Register == "Low"))
propclovoi <- ddply(LowRegStops, c("Subject", "Age", "Sex"), summarise, N = sum(Register == "Low"), clovoi = sum(VOT < 0), propclovoi = clovoi/N)
clovoi <- ggplot(propclovoi, aes(x=Age, y=propclovoi))+ geom_point(aes(color=Sex, shape=Sex),size=2) + labs(y = "prop. of neg. VOT")+ scale_y_continuous(limits = c(0, 1))
clovoi <- clovoi + geom_smooth(method=lm, color="black", size = 0.6, se=FALSE)
clovoi

bmp("Fig 4 Propclovoi.bmp", units="cm", width=10, height=6, res=600)
clovoi
dev.off()

## Difference between closure of high-register and devoiced low-register stops (Table 2 Appendix B)
# Merge stopVOT and PSclo1 to get closure duration by VOT
PSclo <- droplevels(subset(PSclo, t == 1))
PSclo$clodur <- PSclo$seg_End-PSclo$seg_Start
PSclo1 <- droplevels(subset(PSclo, Manner == "stop"))
stopVOT2 <- droplevels(subset(PSop1, Manner=="stop"))
PSclo2 <- PSclo1 
PSclo2[2:61] <- NULL
cloVOT <- merge(x=stopVOT2, y=PSclo2, by.x="Filename", by.y="Filename")
cloposVOT <- droplevels(subset(cloVOT, VOT >= 0))
#cloposVOT$Place <- factor(cloposVOT$Place,levels(cloposVOT$Place)[c(2,1)])

cloposVOTV <- droplevels(subset(cloposVOT, VoiGr == "Voi"))
cloposVOTD <- droplevels(subset(cloposVOT, VoiGr == "Dev"))

# Mixed models for closure duration do not include Vowel, as the number of words with low-register devoicing in each vowel category
# is too low in Voicers, which would lead to radical overfitting. Check with: xtabs(~Vowel+Place+Register, cloposVOTV)

# Voicers
cloposVOTV.lmer <- lmer(clodur~Register*Place+(1|Subject)+(1|Word), cloposVOTV)

# Save models if desired
save(cloposVOTV.lmer, file = "Closure voicing in stops with positive VOT - Voicers.Rdata")
write.csv(summary(cloposVOTV.lmer)$coefficients, "cloposVOTfinalmodelVoicers.csv")

# Devoicers
cloposVOTD.lmer <- lmer(clodur~Register*Place+(1|Subject)+(1|Word), cloposVOTD)

save(cloposVOTD.lmer, file = "Closure voicing in stops with positive VOT - Devoicers.Rdata")
write.csv(summary(cloposVOTD.lmer)$coefficients, "cloposVOTfinalmodelDevoicers.csv")

## Closure duration for various types of stops*register (Table 3) 
clodurposVOT <- ddply(cloposVOT, c("Register", "Place", "VoiGr"), summarise, meanclodur=mean(clodur), sdclodur = sd(clodur), N = length(clodur))
clovoineg <- droplevels(subset(cloVOT, VOT < 0))
clovoinegVOT <- ddply(clovoineg, c("Place", "VoiGr"), summarise, meanclodur=mean(clodur), sdclodur = sd(clodur), N = length(clodur))


### VOWEL CHARTS AND STATS

## Vowel duration (Table 3 in Appendix B)
PSop1$Register <- as.factor(PSop1$Register)
PSop1vd <- droplevels(subset(PSop1, Manner == "stop"))
PSop1vd$vowdur <- PSop1vd$seg_End - PSop1vd$ov
#PSop1vd$Vowel <- factor(PSop1vd$Vowel,levels(PSop1vd$Vowel)[c(3,1,2,4,5)])

VowDur <- ddply(PSop1vd, c("VoiGr", "Register"), summarise, meanVdur = mean(vowdur), N = length(vowdur))

# Devoicers
DevV <- droplevels(subset(PSop1vd, VoiGr == "Dev"))
VLD.lmer <- lmer(vowdur~Register*Place+Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),DevV)
#Dropping Register*Vowel makes the model worse

# Save models if desired
save(VLD.lmer, file = "Vowel duration in Devoicers.Rdata")
write.csv(summary(VLD.lmer)$coefficients, "VowelDurationDevoicers.csv")

# Voicers
VoiV <- droplevels(subset(PSop1vd, VoiGr == "Voi"))
VLV.lmer <- lmer(vowdur~Register*Place+Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),VoiV)
VLV.lmer2 <- lmer(vowdur~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),VoiV)
VLV.lmer3 <- lmer(vowdur~Register+Place*Vowel+(1|Subject)+(1|Word),VoiV)
#Dropping last interaction makes the model worse

# Save models if desired
save(VLV.lmer, file = "Vowel duration in Voicers.Rdata")
write.csv(summary(VLV.lmer)$coefficients, "VowelDurationVoicers.csv")

## Get normalized values for Men and Women, separately (= intuitive variables rescaled based on overall mean and sd per gender) 

Dev <- droplevels(subset(PSop, VoiGr == "Dev"))
Dev$normf0 <- mean(Dev$f0, na.rm=TRUE) + Dev$Zf0 * sd(Dev$f0, na.rm=TRUE)
Dev$normH1H2 <- mean(Dev$H1H2c, na.rm=TRUE) + Dev$ZH1H2c * sd(Dev$H1H2c, na.rm=TRUE)
Dev$normH1A1 <- mean(Dev$H1A1c, na.rm=TRUE) + Dev$ZH1A1c * sd(Dev$H1A1c, na.rm=TRUE)
Dev$normH1A3 <- mean(Dev$H1A3c, na.rm=TRUE) + Dev$ZH1A3c * sd(Dev$H1A3c, na.rm=TRUE)
Dev$normCPP <- mean(Dev$CPP, na.rm=TRUE) + Dev$ZCPP * sd(Dev$CPP, na.rm=TRUE)
Dev$normF1 <- mean(Dev$F1, na.rm=TRUE) + Dev$F1Lob * sd(Dev$F1, na.rm=TRUE)
Dev$normF2 <- mean(Dev$F2, na.rm=TRUE) + Dev$F2Lob * sd(Dev$F2, na.rm=TRUE)

Voi <- droplevels(subset(PSop, VoiGr == "Voi"))
Voi$normf0 <- mean(Voi$f0, na.rm=TRUE) + Voi$Zf0 * sd(Voi$f0, na.rm=TRUE)
Voi$normH1H2 <- mean(Voi$H1H2c, na.rm=TRUE) + Voi$ZH1H2c * sd(Voi$H1H2c, na.rm=TRUE)
Voi$normH1A1 <- mean(Voi$H1A1c, na.rm=TRUE) + Voi$ZH1A1c * sd(Voi$H1A1c, na.rm=TRUE)
Voi$normH1A3 <- mean(Voi$H1A3c, na.rm=TRUE) + Voi$ZH1A3c * sd(Voi$H1A3c, na.rm=TRUE)
Voi$normCPP <- mean(Voi$CPP, na.rm=TRUE) + Voi$ZCPP * sd(Voi$CPP, na.rm=TRUE)
Voi$normF1 <- mean(Voi$F1, na.rm=TRUE) + Voi$F1Lob * sd(Voi$F1, na.rm=TRUE)
Voi$normF2 <- mean(Voi$F2, na.rm=TRUE) + Voi$F2Lob * sd(Voi$F2, na.rm=TRUE)

##F0 (Figure 5)

# Voiced
# First aggregate the data and restructure to get desired charts
f0reg <- ddply(Voi, c("Manner", "Register", "corr_t"), summarise, N = sum(!is.na(normf0)), meanf0 = mean(normf0, na.rm=TRUE), sd = sd(normf0, na.rm=TRUE), se = sd / sqrt(N))
f0reg <- droplevels(subset(f0reg, corr_t < 200))
f0reg$ManReg <- paste(f0reg$Manner, f0reg$Register)
f0reg$Register <- as.character(f0reg$Register)
f0reg[f0reg$Manner == "aspirated",]$Register <- "Aspirated"
f0reg[f0reg$Manner == "implosive",]$Register <- "Implosive"
f0reg[f0reg$Manner == "fricative",]$Register <- "Fricative"
f0reg$Register <- as.factor(f0reg$Register)
f0reg$Manner <- revalue(f0reg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
f0reg$Manner <- factor(f0reg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
f0reg$Register <- factor(f0reg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Draw normalized f0 chart (Fig. 5)
f0chart <- ggplot(f0reg , aes(x=corr_t, y = meanf0, group = ManReg))
f0chart <- f0chart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(.~Manner)
f0chart <- f0chart + geom_ribbon(aes(ymin=meanf0-1.96*se, ymax=meanf0+1.96*se, fill=Register), alpha=0.2) 
f0chart <- f0chart + labs(x = "Time from vowel onset (ms)", y = "normalized f0") + ggtitle("Voicers") + theme(plot.title = element_text(hjust = 0.5))
f0chart <- f0chart + ylim(100, 180)
f0chartV <- f0chart + theme(text = element_text(size=10), legend.title = element_text(size=10))
f0chartV <- f0chart + ylim(90,190)

# Devoiced
# First aggregate the data and restructure to get desired charts
f0reg <- ddply(Dev, c("Manner", "Register", "corr_t"), summarise, N = sum(!is.na(normf0)), meanf0 = mean(normf0, na.rm=TRUE), sd = sd(normf0, na.rm=TRUE), se = sd / sqrt(N))
f0reg <- droplevels(subset(f0reg, corr_t < 200))
f0reg$ManReg <- paste(f0reg$Manner, f0reg$Register)
f0reg$Register <- as.character(f0reg$Register)
f0reg[f0reg$Manner == "aspirated",]$Register <- "Aspirated"
f0reg[f0reg$Manner == "implosive",]$Register <- "Implosive"
f0reg[f0reg$Manner == "fricative",]$Register <- "Fricative"
f0reg$Register <- as.factor(f0reg$Register)
f0reg$Manner <- revalue(f0reg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
f0reg$Manner <- factor(f0reg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
f0reg$Register <- factor(f0reg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Draw normalized f0 chart (Fig. 5)
f0chart <- ggplot(f0reg , aes(x=corr_t, y = meanf0, group = ManReg))
f0chart <- f0chart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(.~Manner)
f0chart <- f0chart + geom_ribbon(aes(ymin=meanf0-1.96*se, ymax=meanf0+1.96*se, fill=Register), alpha=0.2) 
f0chart <- f0chart + labs(x = "Time from vowel onset (ms)", y = "normalized f0")+ ggtitle("Devoicers") + theme(plot.title = element_text(hjust = 0.5))
f0chartDev <- f0chart + theme(text = element_text(size=10), legend.title = element_text(size=10))
f0chartDev <- f0chartDev + ylim(180, 280)

figure <- ggarrange(f0chartV, f0chartDev, ncol = 1, nrow = 2,common.legend = TRUE, legend = "right")
bmp("Fig 5 f0chart.bmp", units="cm", width=15, height=10, res=600)
figure
dev.off()


## H1*-H2* (Figure 6)

# Voicers
# First aggregate the data and restructure to get desired charts
H1H2creg <- ddply(Dev, c("Manner", "Register", "corr_t"), summarise, N = sum(!is.na(normH1H2)), meanH1H2c = mean(normH1H2, na.rm=TRUE), sd = sd(normH1H2, na.rm=TRUE), se = sd / sqrt(N))
H1H2creg <- droplevels(subset(H1H2creg, corr_t < 200))
H1H2creg$ManReg <- paste(H1H2creg$Manner, H1H2creg$Register)
H1H2creg$Register <- as.character(H1H2creg$Register)
H1H2creg[H1H2creg$Manner == "aspirated",]$Register <- "Aspirated"
H1H2creg[H1H2creg$Manner == "implosive",]$Register <- "Implosive"
H1H2creg[H1H2creg$Manner == "fricative",]$Register <- "Fricative"
H1H2creg$Register <- as.factor(H1H2creg$Register)
H1H2creg$Manner <- revalue(H1H2creg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
H1H2creg$Manner <- factor(H1H2creg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
H1H2creg$Register <- factor(H1H2creg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Draw normalized H1H2c chart
H1H2cchart <- ggplot(H1H2creg , aes(x=corr_t, y = meanH1H2c, group = ManReg))
H1H2cchart <- H1H2cchart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(.~Manner)
H1H2cchart <- H1H2cchart + geom_ribbon(aes(ymin=meanH1H2c-1.96*se, ymax=meanH1H2c+1.96*se, fill=Register), alpha=0.2) 
H1H2cchart <- H1H2cchart + labs(x = "Time from vowel onset (ms)", y = "normalized H1*-H2*") + ggtitle("Voicers") + theme(plot.title = element_text(hjust = 0.5))
H1H2cchartV<- H1H2cchart + theme(text = element_text(size=10), legend.title = element_text(size=10))

# Devoicers
#First aggregate the data and restructure to get desired charts
H1H2creg <- ddply(Voi, c("Manner", "Register", "corr_t"), summarise, N = sum(!is.na(normH1H2)), meanH1H2c = mean(normH1H2, na.rm=TRUE), sd = sd(normH1H2, na.rm=TRUE), se = sd / sqrt(N))
H1H2creg <- droplevels(subset(H1H2creg, corr_t < 200))
H1H2creg$ManReg <- paste(H1H2creg$Manner, H1H2creg$Register)
H1H2creg$Register <- as.character(H1H2creg$Register)
H1H2creg[H1H2creg$Manner == "aspirated",]$Register <- "Aspirated"
H1H2creg[H1H2creg$Manner == "implosive",]$Register <- "Implosive"
H1H2creg[H1H2creg$Manner == "fricative",]$Register <- "Fricative"
H1H2creg$Register <- as.factor(H1H2creg$Register)
H1H2creg$Manner <- revalue(H1H2creg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
H1H2creg$Manner <- factor(H1H2creg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
H1H2creg$Register <- factor(H1H2creg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Draw normalized H1H2c chart
H1H2cchart <- ggplot(H1H2creg , aes(x=corr_t, y = meanH1H2c, group = ManReg))
H1H2cchart <- H1H2cchart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(.~Manner)
H1H2cchart <- H1H2cchart + geom_ribbon(aes(ymin=meanH1H2c-1.96*se, ymax=meanH1H2c+1.96*se, fill=Register), alpha=0.2) 
H1H2cchart <- H1H2cchart + labs(x = "Time from vowel onset (ms)", y = "normalized H1*-H2*")+ ggtitle("Devoicers") + theme(plot.title = element_text(hjust = 0.5))
H1H2cchartD <- H1H2cchart + theme(text = element_text(size=10), legend.title = element_text(size=10))

figure <- ggarrange(H1H2cchartV, H1H2cchartD, ncol = 1, nrow = 2,common.legend = TRUE, legend = "right")
bmp("Fig 6 H1H2cchart.bmp", units="cm", width=15, height=10, res=600)
figure
dev.off()


## OTHER SPECTRAL SLOPE MEASURES: 
# H1*-A1* between registers is not clearly distinct for either group, while H1*-A3* is as good as H1*-H2* for men, 
# but quite indistinct for devoicers (lots of F3 measurements were excluded because of tracking errors though, so H1*-H2* is more reliable).


## CPP (Figure 7)

# Voicers
# First aggregate the data and restructure to get desired charts
CPPreg <- ddply(Voi, c("Manner", "Register", "corr_t"), summarise, N = sum(!is.na(normCPP)), meanCPP = mean(normCPP, na.rm=TRUE), sd = sd(normCPP, na.rm=TRUE), se = sd / sqrt(N))
CPPreg <- droplevels(subset(CPPreg, corr_t < 200))
CPPreg$ManReg <- paste(CPPreg$Manner, CPPreg$Register)
CPPreg$Register <- as.character(CPPreg$Register)
CPPreg[CPPreg$Manner == "aspirated",]$Register <- "Aspirated"
CPPreg[CPPreg$Manner == "implosive",]$Register <- "Implosive"
CPPreg[CPPreg$Manner == "fricative",]$Register <- "Fricative"
CPPreg$Register <- as.factor(CPPreg$Register)
CPPreg$Manner <- revalue(CPPreg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
CPPreg$Manner <- factor(CPPreg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
CPPreg$Register <- factor(CPPreg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Draw normalized CPP chart
CPPchart <- ggplot(CPPreg , aes(x=corr_t, y = meanCPP, group = ManReg))
CPPchart <- CPPchart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(.~Manner)
CPPchart <- CPPchart + geom_ribbon(aes(ymin=meanCPP-1.96*se, ymax=meanCPP+1.96*se, fill=Register), alpha=0.2) 
CPPchart <- CPPchart + labs(x = "Time from vowel onset (ms)", y = "normalized CPP") + ggtitle("Voicers") + theme(plot.title = element_text(hjust = 0.5))
CPPchartV <- CPPchart + theme(text = element_text(size=10), legend.title = element_text(size=10))
CPPchartV <- CPPchartV + ylim(15, 25)

# Devoicers
# First aggregate the data and restructure to get desired charts
CPPreg <- ddply(Dev, c("Manner", "Register", "corr_t"), summarise, N = sum(!is.na(normCPP)), meanCPP = mean(normCPP, na.rm=TRUE), sd = sd(normCPP, na.rm=TRUE), se = sd / sqrt(N))
CPPreg <- droplevels(subset(CPPreg, corr_t < 200))
CPPreg$ManReg <- paste(CPPreg$Manner, CPPreg$Register)
CPPreg$Register <- as.character(CPPreg$Register)
CPPreg[CPPreg$Manner == "aspirated",]$Register <- "Aspirated"
CPPreg[CPPreg$Manner == "implosive",]$Register <- "Implosive"
CPPreg[CPPreg$Manner == "fricative",]$Register <- "Fricative"
CPPreg$Register <- as.factor(CPPreg$Register)
CPPreg$Manner <- revalue(CPPreg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
CPPreg$Manner <- factor(CPPreg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
CPPreg$Register <- factor(CPPreg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Draw normalized CPP chart
CPPchart <- ggplot(CPPreg , aes(x=corr_t, y = meanCPP, group = ManReg))
CPPchart <- CPPchart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(.~Manner)
CPPchart <- CPPchart + geom_ribbon(aes(ymin=meanCPP-1.96*se, ymax=meanCPP+1.96*se, fill=Register), alpha=0.2) 
CPPchart <- CPPchart + labs(x = "Time from vowel onset (ms)", y = "normalized CPP")+ ggtitle("Devoicers") + theme(plot.title = element_text(hjust = 0.5))
CPPchartD <- CPPchart + theme(text = element_text(size=10), legend.title = element_text(size=10))
CPPchartD <- CPPchartD + ylim(17.5, 27.5)

figure <- ggarrange(CPPchartV, CPPchartD, ncol = 1, nrow = 2,common.legend = TRUE, legend = "right")
bmp("Fig 7 CPPchart.bmp", units="cm", width=15, height=10, res=600)
figure
dev.off()


## FORMANTS

# Convert vowel names in IPA
Voi$Vowel <- as.character(Voi$Vowel)
Voi[Voi$Vowel == "i",]$Vowel <- "i\U02D0"
Voi[Voi$Vowel == "u",]$Vowel <- "u\U02D0"
Voi[Voi$Vowel == "a",]$Vowel <- "a\U02D0"
Voi[Voi$Vowel == "E",]$Vowel <- "\U0190\U02D0"
Voi[Voi$Vowel == "O",]$Vowel <- "\U0186\U02D0"
Voi$Vowel <- as.factor(Voi$Vowel)

Dev$Vowel <- as.character(Dev$Vowel)
Dev[Dev$Vowel == "i",]$Vowel <- "i\U02D0"
Dev[Dev$Vowel == "u",]$Vowel <- "u\U02D0"
Dev[Dev$Vowel == "a",]$Vowel <- "a\U02D0"
Dev[Dev$Vowel == "E",]$Vowel <- "\U0190\U02D0"
Dev[Dev$Vowel == "O",]$Vowel <- "\U0186\U02D0"
Dev$Vowel <- as.factor(Dev$Vowel)


## F1 (Figure 8)

# Voicers
# First aggregate the data
F1reg <- ddply(Voi, c("Manner", "Register", "Vowel", "corr_t"), summarise, N = sum(!is.na(normF1)), meanF1 = mean(normF1, na.rm=TRUE), sd = sd(normF1, na.rm=TRUE), se = sd / sqrt(N))
F1reg <- droplevels(subset(F1reg, corr_t < 200))
F1reg$ManReg <- paste(F1reg$Manner, F1reg$Register)
F1reg$Register <- as.character(F1reg$Register)
F1reg[F1reg$Manner == "aspirated",]$Register <- "Aspirated"
F1reg[F1reg$Manner == "implosive",]$Register <- "Implosive"
F1reg[F1reg$Manner == "fricative",]$Register <- "Fricative"
F1reg$Register <- as.factor(F1reg$Register)
F1reg$Manner <- revalue(F1reg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
F1reg$Manner <- factor(F1reg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
F1reg$Register <- factor(F1reg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Create fake frame so that relevant rows have the same range (used in geom_point below)
fakeframe <- data.frame(Manner = c("Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents"), Vowel = c("a\U02D0","\U0190\U02D0","i\U02D0","\U0186\U02D0","u\U02D0","a\U02D0","\U0190\U02D0","i\U02D0","\U0186\U02D0","u\U02D0"),meanF1 = c(400,400,200,400,200,900,900,700,900,700),
corr_t = c(1,1,1,1,1,1,1,1,1,1),N = c(1,1,1,1,1,1,1,1,1,1), sd = c(1,1,1,1,1,1,1,1,1,1),se = c(1,1,1,1,1,1,1,1,1,1), Register=c("Aspirated","Aspirated","Aspirated","Aspirated","Aspirated","Implosive","Implosive","Implosive","Implosive","Implosive"), ManReg = c("bou","bou","bou","bou","bou","bi","bi","bi","bi","bi"))
F1reg <- rbind(F1reg, fakeframe)
F1reg$Vowel <- factor(F1reg$Vowel,levels(F1reg$Vowel)[c(4,5,2,1,3)])

# Draw normalized f1 chart
F1chart <- ggplot(F1reg , aes(x=corr_t, y = meanF1, group = ManReg))
F1chart <- F1chart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(Vowel~Manner, scales = "free_y")
F1chart <- F1chart + geom_ribbon(aes(ymin=meanF1-1.96*se, ymax=meanF1+1.96*se, fill=Register), alpha=0.2) 
F1chart <- F1chart + labs(x = "Time from vowel onset (ms)", y = "normalized F1")+ ggtitle("Voicers") + theme(plot.title = element_text(hjust = 0.5))
F1chartV <- F1chart + theme(text = element_text(size=10), legend.title = element_text(size=10))

# Devoicers
# First aggregate the data
F1reg <- ddply(Dev, c("Manner", "Register", "Vowel", "corr_t"), summarise, N = sum(!is.na(normF1)), meanF1 = mean(normF1, na.rm=TRUE), sd = sd(normF1, na.rm=TRUE), se = sd / sqrt(N))
F1reg <- droplevels(subset(F1reg, corr_t < 200))
F1reg$ManReg <- paste(F1reg$Manner, F1reg$Register)
F1reg$Register <- as.character(F1reg$Register)
F1reg[F1reg$Manner == "aspirated",]$Register <- "Aspirated"
F1reg[F1reg$Manner == "implosive",]$Register <- "Implosive"
F1reg[F1reg$Manner == "fricative",]$Register <- "Fricative"
F1reg$Register <- as.factor(F1reg$Register)
F1reg$Manner <- revalue(F1reg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
F1reg$Manner <- factor(F1reg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
F1reg$Register <- factor(F1reg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Create fake frame so that relevant rows have the same range (used in geom_point below)
fakeframe <- data.frame(Manner = c("Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents"), Vowel = c("a\U02D0","\U0190\U02D0","i\U02D0","\U0186\U02D0","u\U02D0","a\U02D0","\U0190\U02D0","i\U02D0","\U0186\U02D0","u\U02D0"),meanF1 = c(500,500,200,500,200,1000,1000,700,1000,700),
corr_t = c(1,1,1,1,1,1,1,1,1,1),N = c(1,1,1,1,1,1,1,1,1,1), sd = c(1,1,1,1,1,1,1,1,1,1),se = c(1,1,1,1,1,1,1,1,1,1), Register=c("Aspirated","Aspirated","Aspirated","Aspirated","Aspirated","Implosive","Implosive","Implosive","Implosive","Implosive"), ManReg = c("bou","bou","bou","bou","bou","bi","bi","bi","bi","bi"))
F1reg <- rbind(F1reg, fakeframe)
F1reg <- rbind(F1reg, fakeframe)
F1reg$Vowel <- factor(F1reg$Vowel,levels(F1reg$Vowel)[c(4,5,2,1,3)])

# Draw normalized f1 chart
F1chart <- ggplot(F1reg, aes(x=corr_t, y = meanF1, group = ManReg))
F1chart <- F1chart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(Vowel~Manner, scales = "free_y")
F1chart <- F1chart + geom_ribbon(aes(ymin=meanF1-1.96*se, ymax=meanF1+1.96*se, fill=Register), alpha=0.2) 
F1chart <- F1chart + labs(x = "Time from vowel onset (ms)", y = "normalized F1")+ ggtitle("Devoicers") + theme(plot.title = element_text(hjust = 0.5))
F1chartD <- F1chart + theme(text = element_text(size=10), legend.title = element_text(size=10))

figure <- ggarrange(F1chartV, F1chartD, ncol = 1, nrow = 2,common.legend = TRUE, legend = "right")
bmp("Fig 8 F1chart.bmp", units="cm", width=15, height=20, res=600)
figure
dev.off()


## F2 (Figure 9)

# Voicers
# First aggregate the data
F2reg <- ddply(Dev, c("Manner", "Register", "Vowel", "corr_t"), summarise, N = sum(!is.na(normF2)), meanF2 = mean(normF2, na.rm=TRUE), sd = sd(normF2, na.rm=TRUE), se = sd / sqrt(N))
F2reg <- droplevels(subset(F2reg, corr_t < 200))
F2reg$ManReg <- paste(F2reg$Manner, F2reg$Register)
F2reg$Register <- as.character(F2reg$Register)
F2reg[F2reg$Manner == "aspirated",]$Register <- "Aspirated"
F2reg[F2reg$Manner == "implosive",]$Register <- "Implosive"
F2reg[F2reg$Manner == "fricative",]$Register <- "Fricative"
F2reg$Register <- as.factor(F2reg$Register)
F2reg$Manner <- revalue(F2reg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
F2reg$Manner <- factor(F2reg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
F2reg$Register <- factor(F2reg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Create fake frame so that rows have the same range (used in geom_point below)
fakeframe <- data.frame(Manner = c("Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents"), Vowel = c("a\U02D0","\U0190\U02D0","i\U02D0","\U0186\U02D0","u\U02D0","a\U02D0","\U0190\U02D0","i\U02D0","\U0186\U02D0","u\U02D0"),meanF2 = c(1300,1900,2300,1000,700,2100,2700,3100,1800,1500),
corr_t = c(1,1,1,1,1,1,1,1,1,1),N = c(1,1,1,1,1,1,1,1,1,1), sd = c(1,1,1,1,1,1,1,1,1,1),se = c(1,1,1,1,1,1,1,1,1,1), Register=c("Aspirated","Aspirated","Aspirated","Aspirated","Aspirated","Implosive","Implosive","Implosive","Implosive","Implosive"), ManReg = c("bou","bou","bou","bou","bou","bi","bi","bi","bi","bi"))
F2reg <- rbind(F2reg, fakeframe)
F2reg$Vowel <- factor(F2reg$Vowel,levels(F2reg$Vowel)[c(4,5,2,1,3)])

# Draw normalized F2 chart
F2chart <- ggplot(F2reg , aes(x=corr_t, y = meanF2, group = ManReg))
F2chart <- F2chart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(Vowel~Manner, scales = "free_y")
F2chart <- F2chart + geom_ribbon(aes(ymin=meanF2-1.96*se, ymax=meanF2+1.96*se, fill=Register), alpha=0.2) 
F2chart <- F2chart + labs(x = "Time from vowel onset (ms)", y = "normalized F2")+ ggtitle("Voicers") + theme(plot.title = element_text(hjust = 0.5))
F2chartV <- F2chart + theme(text = element_text(size=10), legend.title = element_text(size=10))

# Devoicers
# First aggregate the data
F2reg <- ddply(Voi, c("Manner", "Register", "Vowel", "corr_t"), summarise, N = sum(!is.na(normF2)), meanF2 = mean(normF2, na.rm=TRUE), sd = sd(normF2, na.rm=TRUE), se = sd / sqrt(N))
F2reg <- droplevels(subset(F2reg, corr_t < 200))
F2reg$ManReg <- paste(F2reg$Manner, F2reg$Register)
F2reg$Register <- as.character(F2reg$Register)
F2reg[F2reg$Manner == "aspirated",]$Register <- "Aspirated"
F2reg[F2reg$Manner == "implosive",]$Register <- "Implosive"
F2reg[F2reg$Manner == "fricative",]$Register <- "Fricative"
F2reg$Register <- as.factor(F2reg$Register)
F2reg$Manner <- revalue(F2reg$Manner, c("sonorant"="Sonorants", "stop"="Stops", "aspirated"="Other Obstruents", "fricative"="Other Obstruents", "implosive"="Other Obstruents"))
F2reg$Manner <- factor(F2reg$Manner, levels = c("Stops", "Sonorants", "Other Obstruents"))
F2reg$Register <- factor(F2reg$Register, levels = c("High", "Neutral", "Low", "Aspirated", "Implosive", "Fricative"))

# Create fake frame so that rows have the same range (used in geom_point below)
fakeframe <- data.frame(Manner = c("Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents","Other Obstruents"), Vowel = c("a\U02D0","\U0190\U02D0","i\U02D0","\U0186\U02D0","u\U02D0","a\U02D0","\U0190\U02D0","i\U02D0","\U0186\U02D0","u\U02D0"),meanF2 = c(1300,1600,2000,800,750,2100,2400,2800,1600,1550),
corr_t = c(1,1,1,1,1,1,1,1,1,1),N = c(1,1,1,1,1,1,1,1,1,1), sd = c(1,1,1,1,1,1,1,1,1,1),se = c(1,1,1,1,1,1,1,1,1,1), Register=c("Aspirated","Aspirated","Aspirated","Aspirated","Aspirated","Implosive","Implosive","Implosive","Implosive","Implosive"), ManReg = c("bou","bou","bou","bou","bou","bi","bi","bi","bi","bi"))
F2reg <- rbind(F2reg, fakeframe)
F2reg$Vowel <- factor(F2reg$Vowel,levels(F2reg$Vowel)[c(4,5,2,1,3)])

# Draw normalized F2 chart
F2chart <- ggplot(F2reg , aes(x=corr_t, y = meanF2, group = ManReg))
F2chart <- F2chart + geom_line(aes(color=Register, linetype=Register), size =1)+ facet_grid(Vowel~Manner, scales = "free_y")
F2chart <- F2chart + geom_ribbon(aes(ymin=meanF2-1.96*se, ymax=meanF2+1.96*se, fill=Register), alpha=0.2) 
F2chart <- F2chart + labs(x = "Time from vowel onset (ms)", y = "normalized F2")+ ggtitle("Devoicers") + theme(plot.title = element_text(hjust = 0.5))
F2chartD <- F2chart + theme(text = element_text(size=10), legend.title = element_text(size=10))

figure <- ggarrange(F2chartV, F2chartD, ncol = 1, nrow = 2,common.legend = TRUE, legend = "right")
bmp("Fig 9 F2chart.bmp", units="cm", width=15, height=20, res=600)
figure
dev.off()


## MIXED MODELS FOR REGISTER
# Fitted on normalized (i.e. rescaled) values
# Normalized f0 (models with random slopes are singular, so only use random intercepts)

## Prepare data sets for mixed models
# Only keep first measure after stops, and set O and velars as references
PSopstopV <- droplevels(subset(Voi, Manner == "stop" & corr_t == 1))
PSopstopV$Place <- factor(PSopstopV$Place,levels(PSopstopV$Place)[c(2,1)])
#PSopstopV$Vowel <- factor(PSopstopV$Vowel,levels(PSopstopV$Vowel)[c(4,1,2,3,5)])

PSopstopD <- droplevels(subset(Dev, Manner == "stop" & corr_t == 1))
PSopstopD$Place <- factor(PSopstopD$Place,levels(PSopstopD$Place)[c(2,1)])
#PSopstopD$Vowel <- factor(PSopstopD$Vowel,levels(PSopstopD$Vowel)[c(4,1,2,3,5)])

# Keep first measure after sonorants, and set O and velars as references
PSopstopVs <- droplevels(subset(Voi, Manner == "sonorant" & corr_t == 1))
PSopstopVs$Place <- factor(PSopstopVs$Place,levels(PSopstopVs$Place)[c(2,1)])
#PSopstopVs$Vowel <- factor(PSopstopVs$Vowel,levels(PSopstopVs$Vowel)[c(4,1,2,3,5)])

PSopstopDs <- droplevels(subset(Dev, Manner == "sonorant" & corr_t == 1))
PSopstopDs$Place <- factor(PSopstopDs$Place,levels(PSopstopDs$Place)[c(2,1)])
#PSopstopDs$Vowel <- factor(PSopstopDs$Vowel,levels(PSopstopDs$Vowel)[c(4,1,2,3,5)])

## Mixed models on F0 (Tables 4 and 5 in Appendix B)

# Voicers; Stops at t = 1, small interactional effect of register in some vowels
Vf0reg.lmer <- lmer(normf0~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopV)
Vf0reg.lmer2 <- lmer(normf0~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopV)
Vf0reg.lmer3 <- lmer(normf0~Register*Vowel+Place+(1|Subject)+(1|Word),PSopstopV)
Vf0reg.lmer4 <- lmer(normf0~Register*Vowel+(1|Subject)+(1|Word),PSopstopV)
#Stop here as dropping the interaction makes the model AIC worse

# Save models if needed
save(Vf0reg.lmer4, file = "f0finalmodelV.Rdata")
write.csv(summary(Vf0reg.lmer4)$coefficients, "f0finalmodelV.csv")

# Voicers; Stops at t = 5, the register effect is only a bit stronger than at t = 1
PSopstopV5 <- droplevels(subset(Voi, Manner == "stop" & corr_t == 5))
PSopstopV5$Place <- factor(PSopstopV5$Place,levels(PSopstopV5$Place)[c(2,1)])
#PSopstopV5$Vowel <- factor(PSopstopV5$Vowel,levels(PSopstopV5$Vowel)[c(4,1,2,3,5)])
Vf0reg5.lmer <- lmer(normf0~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopV5)
Vf0reg5.lmer2 <- lmer(normf0~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopV5)
Vf0reg5.lmer3 <- lmer(normf0~Register*Vowel+Place+(1|Subject)+(1|Word),PSopstopV5)
Vf0reg5.lmer4 <- lmer(normf0~Register*Vowel+(1|Subject)+(1|Word),PSopstopV5)
#Stop here as dropping interaction makes the model AIC worse

# Voicers; Sonorants at t = 1, main effect of register in O largely cancelled out in other vowels by interactions
Vsf0reg.lmer <- lmer(normf0~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopVs)
Vsf0reg.lmer2 <- lmer(normf0~Register*Vowel+Register*Place+(1|Subject)+(1|Word),PSopstopVs)
Vsf0reg.lmer3 <- lmer(normf0~Register*Vowel+Place+(1|Subject)+(1|Word),PSopstopVs)
Vsf0reg.lmer4 <- lmer(normf0~Register*Vowel+(1|Subject)+(1|Word),PSopstopVs)
#Stop here as dropping interaction makes the model AIC worse

# Save model if needed
save(Vsf0reg.lmer4, file = "f0sonfinalmodelVs.Rdata")
write.csv(summary(Vsf0reg.lmer4)$coefficients, "f0sonfinalmodelV.csv")

# Devoicers; Stops at t =1, no effect of register
Df0reg.lmer <- lmer(normf0~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopD)
Df0reg.lmer2 <- lmer(normf0~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopD)
Df0reg.lmer3 <- lmer(normf0~Register+Place*Vowel+(1|Subject)+(1|Word),PSopstopD)
Df0reg.lmer4 <- lmer(normf0~Register+Place+Vowel+(1|Subject)+(1|Word),PSopstopD)
Df0reg.lmer5 <- lmer(normf0~Register+Vowel+(1|Subject)+(1|Word),PSopstopD)
Df0reg.lmer6 <- lmer(normf0~Vowel+(1|Subject)+(1|Word),PSopstopD)
#Some vowel levels are significant, so stop here

# Save model if needed
save(Df0reg.lmer6, file = "f0finalmodelD.Rdata")
write.csv(summary(Df0reg.lmer6)$coefficients, "f0finalmodelD.csv")

# Devoicers; Stops at t = 5, no effect of register either
PSopstopD5 <- droplevels(subset(Dev, Manner == "stop" & corr_t == 5))
PSopstopD5$Place <- factor(PSopstopD5$Place,levels(PSopstopD5$Place)[c(2,1)])
#PSopstopD5$Vowel <- factor(PSopstopD5$Vowel,levels(PSopstopD5$Vowel)[c(4,1,2,3,5)])
Df0reg5.lmer <- lmer(normf0~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopD5)
Df0reg5.lmer2 <- lmer(normf0~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopD5, control = lmerControl(optimizer = "optimx", calc.derivs = FALSE,
	optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE, maxit=50000000, iter.max=50000000, eval.max=50000000)))
Df0reg5.lmer3 <- lmer(normf0~Register+Place*Vowel+(1|Subject)+(1|Word),PSopstopD5)
Df0reg5.lmer4 <- lmer(normf0~Register+Place+Vowel+(1|Subject)+(1|Word),PSopstopD5)
Df0reg5.lmer5 <- lmer(normf0~Register+Vowel+(1|Subject)+(1|Word),PSopstopD5)
Df0reg5.lmer6 <- lmer(normf0~Vowel+(1|Subject)+(1|Word),PSopstopD5)
Df0reg5.lmer7 <- lmer(normf0~1+(1|Subject)+(1|Word),PSopstopD5)
#Dropping last fixed factor makes AIC worse 

# Devoicers; weak effect in coronal sonorants
Dsf0reg.lmer <- lmer(normf0~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopDs)
Dsf0reg.lmer2 <- lmer(normf0~Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopDs)
#Dropping Vowel*Place makes the model worse

# Save model if needed
save(Dsf0reg.lmer2, file = "f0sonfinalmodelD.Rdata")
write.csv(summary(Dsf0reg.lmer)$coefficients, "f0sonfinalmodelD.csv")


## H1*-H2* (Tables 6 and 7 in Appendix B)

# Voicers, Stops at t = 1, strong effect of register
VH1H2reg.lmer <- lmer(normH1H2~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopV)
VH1H2reg.lmer2 <- lmer(normH1H2~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopV)
# Dropping Register*Vowel yields a model with a significantly higher AIC

# Save model if needed
save(VH1H2reg.lmer2, file = "H1H2finalmodelV.Rdata")
write.csv(summary(VH1H2reg.lmer2)$coefficients, "H1H2finalmodelV.csv")

# Voicers, sonorants at t = 1, no effect of register
VsH1H2reg.lmer <- lmer(normH1H2~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopVs)
VsH1H2reg.lmer2 <- lmer(normH1H2~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopVs)
VsH1H2reg.lmer3 <- lmer(normH1H2~Register+Place*Vowel+(1|Subject)+(1|Word),PSopstopVs)
VsH1H2reg.lmer4 <- lmer(normH1H2~Register+Place+Vowel+(1|Subject)+(1|Word),PSopstopVs)
# Removing Place makes the AIC worse

# Save model if needed
save(VsH1H2reg.lmer2, file = "H1H2sonfinalmodelV.Rdata")
write.csv(summary(VsH1H2reg.lmer2)$coefficients, "H1H2sonfinalmodelV.csv")

# Devoicers, Stops at t = 1, effect in low vowels only
DH1H2reg.lmer <- lmer(normH1H2~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopD)
DH1H2reg.lmer2 <- lmer(normH1H2~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopD)
DH1H2reg.lmer3 <- lmer(normH1H2~Register*Vowel+Place+(1|Subject)+(1|Word),PSopstopD)
# Can't remove last interaction as it is significant 

# Save model if needed
save(DH1H2reg.lmer3, file = "H1H2finalmodelD.Rdata")
write.csv(summary(DH1H2reg.lmer3)$coefficients, "H1H2finalmodelD.csv")

# Devoicers, Sonorants at t = 1, no effect
DsH1H2reg.lmer <- lmer(normH1H2~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopDs)
DsH1H2reg.lmer2 <- lmer(normH1H2~Register*Vowel+Register*Place+(1|Subject)+(1|Word),PSopstopDs)
# Dropping Register*Vowel makes AIC worse

# Save model if needed
save(DsH1H2reg.lmer2, file = "H1H2sonfinalmodelD.Rdata")
write.csv(summary(DsH1H2reg.lmer2)$coefficients, "H1H2sonfinalmodelD.csv")


## CPP (Tables 8 and 9 in Appendix B)

# Voicers, Stops at t = 1, register significant, strong effect
VCPPreg.lmer <- lmer(normCPP~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopV)
VCPPreg.lmer2 <- lmer(normCPP~Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopV, control = lmerControl(optimizer = "optimx", calc.derivs = FALSE,
	optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE, maxit=50000000, iter.max=50000000, eval.max=50000000)))
VCPPreg.lmer3 <- lmer(normCPP~Register+Place*Vowel+(1|Subject)+(1|Word),PSopstopV)
#Removing last interaction results in a significantly worse AIC

# Save model if needed
save(VCPPreg.lmer3, file = "CPPfinalmodelV.Rdata")
write.csv(summary(VCPPreg.lmer3)$coefficients, "CPPfinalmodelV.csv")

# Voicers, Sonorants at t = 1, register significant, small but robust effect
VsCPPreg.lmer <- lmer(normCPP~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopVs, control = lmerControl(optimizer = "optimx", calc.derivs = FALSE,
	optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE, maxit=50000000, iter.max=50000000, eval.max=50000000)))
VsCPPreg.lmer2 <- lmer(normCPP~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopVs)
VsCPPreg.lmer3 <- lmer(normCPP~Register*Vowel+Place+(1|Subject)+(1|Word),PSopstopVs)
VsCPPreg.lmer4 <- lmer(normCPP~Register*Vowel+(1|Subject)+(1|Word),PSopstopVs)
# Removing interaction makes AIC worse

# Save model if needed
save(VsCPPreg.lmer4, file = "CPPsonfinalmodelV.Rdata")
write.csv(summary(VsCPPreg.lmer4)$coefficients, "CPPsonfinalmodelV.csv")

# Devoicers, Stops at t = 1, real effect, but not significant
DCPPreg.lmer <- lmer(normCPP~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopD)
#Removing Register*Vowel yields a significantly worse AIC

# Save model if needed
save(DCPPreg.lmer, file = "CPPfinalmodelD.Rdata")
write.csv(summary(DCPPreg.lmer)$coefficients, "CPPfinalmodelD.csv")

# Devoicers, Sonorants at t = 1, register significant, small but robust effect
DsCPPreg.lmer <- lmer(normCPP~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopDs, control = lmerControl(optimizer = "optimx", calc.derivs = FALSE,
	optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE, maxit=50000000, iter.max=50000000, eval.max=50000000)))
DsCPPreg.lmer2 <- lmer(normCPP~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopDs)
DsCPPreg.lmer3 <- lmer(normCPP~Register*Vowel+Place+(1|Subject)+(1|Word),PSopstopDs)
DsCPPreg.lmer4 <- lmer(normCPP~Register*Vowel+(1|Subject)+(1|Word),PSopstopDs)
DsCPPreg.lmer5 <- lmer(normCPP~Register+Vowel+(1|Subject)+(1|Word),PSopstopDs)
# Can't simplify further as all remaining effect are significant

# Save model if needed
save(DsCPPreg.lmer5, file = "CPPsonfinalmodelD.Rdata")
write.csv(summary(DsCPPreg.lmer5)$coefficients, "CPPsonfinalmodelD.csv")


## F1 (Tables 10 and 11 in Appendix B)

# Voicers, Stops at = 1, strong effect of register, but weaker in high vowels
VF1reg.lmer <- lmer(normF1~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopV)
VF1reg.lmer2 <- lmer(normF1~Register*Vowel+Register*Place+(1|Subject)+(1|Word),PSopstopV)
# Dropping Register*Place makes the AIC worse

# Save model if needed
save(VF1reg.lmer2, file = "F1finalmodelV.Rdata")
write.csv(summary(VF1reg.lmer2)$coefficients, "F1finalmodelV.csv")

# Voicers, Sonorants at = 1, weak, non-significant effect of register
VsF1reg.lmer <- lmer(normF1~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopVs)
VsF1reg.lmer2 <- lmer(normF1~Register*Vowel+Register*Place+(1|Subject)+(1|Word),PSopstopVs) 
# Dropping Register*Vowel makes AIC worse 

# Save model if needed
save(VsF1reg.lmer2, file = "F1sonfinalmodelV.Rdata")
write.csv(summary(VsF1reg.lmer2)$coefficients, "F1sonfinalmodelV.csv")

# Devoicers, Stops at = 1, strong effect of register, but weaker in high vowels
DF1reg.lmer <- lmer(normF1~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopD)
# Removing Vowel*Place makes the AIC worse

# Save model if needed
save(DF1reg.lmer, file = "F1finalmodelD.Rdata")
write.csv(summary(DF1reg.lmer)$coefficients, "F1finalmodelD.csv")

# Devoicers, Sonorants at = 1, substantial effect of register
DsF1reg.lmer <- lmer(normF1~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopDs) 
DsF1reg.lmer2 <- lmer(normF1~Register*Vowel+Register*Place+(1|Subject)+(1|Word),PSopstopDs) 
DsF1reg.lmer3 <- lmer(normF1~Vowel+Register*Place+(1|Subject)+(1|Word),PSopstopDs, control = lmerControl(optimizer = "optimx", calc.derivs = FALSE,
	optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE, maxit=50000000, iter.max=50000000, eval.max=50000000))) 
DsF1reg.lmer4 <- lmer(normF1~Register+Place+Vowel+(1|Subject)+(1|Word),PSopstopDs)
## Dropping main effects makes AIC worse

# Save model if needed
save(DsF1reg.lmer2, file = "F1sonfinalmodelD.Rdata")
write.csv(summary(DsF1reg.lmer2)$coefficients, "F1sonfinalmodelD.csv")


## F2 (Tables 12 and 13 in Appendix B)

# Voicers, Stops at t = 1, no effect of register
VF2reg.lmer <- lmer(normF2~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopV)
#Removing any interaction makes AIC worse

# Save models if desired
save(VF2reg.lmer, file = "F2finalmodelV.Rdata")
write.csv(summary(VF2reg.lmer)$coefficients, "F2finalmodelV.csv")

# Voicers, Sonorants at t = 1, no effect of register
VsF2reg.lmer <- lmer(normF2~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopVs, control = lmerControl(optimizer = "optimx", calc.derivs = FALSE,
	optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE, maxit=50000000, iter.max=50000000, eval.max=50000000)))
VsF2reg.lmer2 <- lmer(normF2~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopVs)
#Dropping Register*Place makes AIC worse

# Save models if desired
save(VsF2reg.lmer2, file = "F2sonfinalmodelV.Rdata")
write.csv(summary(VsF2reg.lmer)$coefficients, "F2sonfinalmodelV.csv")

# Devoicers, Stops at t = 1, no effect of register
DF2reg.lmer <- lmer(normF2~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopD, control = lmerControl(optimizer = "optimx", calc.derivs = FALSE,
	optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE, maxit=50000000, iter.max=50000000, eval.max=50000000)))
DF2reg.lmer2 <- lmer(normF2~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopD) 
#Removing Register*Vowel makes AIC worse

# Save models if desired
save(DF2reg.lmer2, file = "F2finalmodelD.Rdata")
write.csv(summary(DF2reg.lmer2)$coefficients, "F2finalmodelD.csv")

# Devoicers, Sonorants at t = 1, no effect of register
DsF2reg.lmer <- lmer(normF2~Register*Vowel+Register*Place+Place*Vowel+(1|Subject)+(1|Word),PSopstopDs) 
DsF2reg.lmer2 <- lmer(normF2~Register*Vowel+Place*Vowel+(1|Subject)+(1|Word),PSopstopDs) 
#Removing Register*Vowel makes AIC worse

# Save models if desired
save(DsF2reg.lmer2, file = "F2sonfinalmodelD.Rdata")
write.csv(summary(DsF2reg.lmer)$coefficients, "F2sonfinalmodelD.csv")


### Trade off between type of low register voicing and register cues (Figure 10)

## By token:  no evidence of a compensatory relation
# Same results if the same tests are applied to the 4 speakers who have the most balanced proportions 
# of voiced and voiceless low register stops ("F4", "F7", "M5", "M7")

PSop2 <- droplevels(subset(PSop, Manner == "stop" & corr_t < 200))
PSop2$typereg2 <- rep("High")
PSop2[PSop2$Manner == "stop" & PSop2$VOT < 0,]$typereg2 <- "Low with neg. VOT"
PSop2[PSop2$Register == "Low" & PSop2$VOT >= 0,]$typereg2 <- "Low devoiced"
PSop2$typereg2 <- as.factor(PSop2$typereg2)
PSop2$typereg2 <- factor(PSop2$typereg2,levels(PSop2$typereg2)[c(1,2,3)])

# F0
f0reg2 <- ddply(PSop2, c("corr_t", "typereg2"), summarise, N = sum(!is.na(normf0)), meanZf0 = mean(normf0, na.rm=TRUE), sd = sd(normf0, na.rm=TRUE), se = sd / sqrt(N))
f0chartreg2 <- ggplot(f0reg2, aes(x=corr_t, y = meanZf0, group = typereg2))
f0chartreg2 <- f0chartreg2 + geom_line(aes(color=typereg2, linetype=typereg2), size =1)
f0chartreg2 <- f0chartreg2 + geom_ribbon(aes(ymin=meanZf0-1.96*se, ymax=meanZf0+1.96*se, fill=typereg2), alpha=0.2)
f0chartreg2 <- f0chartreg2 + labs(linetype = "Type of register", fill = "Type of register", color = "Type of register")
f0chartreg2 <- f0chartreg2 + labs(x = "Time from vowel onset (ms)", y = "f0 (normalized Hz)")
f0chartreg2 <- f0chartreg2 + theme(text = element_text(size=10), legend.title = element_text(size=10))
f0chartreg2

# CPP
CPPreg2 <- ddply(PSop2, c("corr_t", "typereg2"), summarise, N = sum(!is.na(normCPP)), meanZCPP = mean(normCPP, na.rm=TRUE), sd = sd(normCPP, na.rm=TRUE), se = sd / sqrt(N))
CPPchartreg2 <- ggplot(CPPreg2, aes(x=corr_t, y = meanZCPP, group = typereg2))
CPPchartreg2 <- CPPchartreg2 + geom_line(aes(color=typereg2, linetype=typereg2), size =1)
CPPchartreg2 <- CPPchartreg2 + geom_ribbon(aes(ymin=meanZCPP-1.96*se, ymax=meanZCPP+1.96*se, fill=typereg2), alpha=0.2)
CPPchartreg2 <- CPPchartreg2 + labs(linetype = "Type of register", fill = "Type of register", color = "Type of register")
CPPchartreg2 <- CPPchartreg2 + labs(x = "Time from vowel onset (ms)", y = "CPP (normalized dB)")
CPPchartreg2 <- CPPchartreg2 + theme(text = element_text(size=10), legend.title = element_text(size=10))
CPPchartreg2

# H1*-H2*
H1H2reg2 <- ddply(PSop2, c("corr_t", "typereg2"), summarise, N = sum(!is.na(normH1H2)), meanZH1H2c = mean(normH1H2, na.rm=TRUE), sd = sd(normH1H2, na.rm=TRUE), se = sd / sqrt(N))
H1H2chartreg2 <- ggplot(H1H2reg2, aes(x=corr_t, y = meanZH1H2c, group = typereg2))
H1H2chartreg2 <- H1H2chartreg2 + geom_line(aes(color=typereg2, linetype=typereg2), size =1)
H1H2chartreg2 <- H1H2chartreg2 + geom_ribbon(aes(ymin=meanZH1H2c-1.96*se, ymax=meanZH1H2c+1.96*se, fill=typereg2), alpha=0.2)
H1H2chartreg2 <- H1H2chartreg2 + labs(linetype = "Type of register", fill = "Type of register", color = "Type of register")
H1H2chartreg2 <- H1H2chartreg2 + labs(x = "Time from vowel onset (ms)", y = "H1*-H2* (normalized dB)")
H1H2chartreg2 <- H1H2chartreg2 + theme(text = element_text(size=10), legend.title = element_text(size=10))
H1H2chartreg2

# F1
F1reg2 <- ddply(PSop2, c("corr_t", "typereg2"), summarise, N = sum(!is.na(normF1)), meanZF1 = mean(normF1, na.rm=TRUE), sd = sd(normF1, na.rm=TRUE), se = sd / sqrt(N))
F1chartreg2 <- ggplot(F1reg2, aes(x=corr_t, y = meanZF1, group = typereg2))
F1chartreg2 <- F1chartreg2 + geom_line(aes(color=typereg2, linetype=typereg2), size =1)
F1chartreg2 <- F1chartreg2 + geom_ribbon(aes(ymin=meanZF1-1.96*se, ymax=meanZF1+1.96*se, fill=typereg2), alpha=0.2)
F1chartreg2 <- F1chartreg2 + labs(linetype = "Type of register", fill = "Type of register", color = "Type of register")
F1chartreg2 <- F1chartreg2 + labs(x = "Time from vowel onset (ms)", y = "F1 (normalized Hz)")
F1chartreg2 <- F1chartreg2 + theme(text = element_text(size=10), legend.title = element_text(size=10))
F1chartreg2

# Trade-off chart(Figure 10)
f0chartreg2 <- f0chartreg2 + theme(axis.title.x=element_text(size=8))
H1H2chartreg2 <- H1H2chartreg2 + theme(axis.title.x=element_text(size=8))
CPPchartreg2 <- CPPchartreg2 + theme(axis.title.x=element_text(size=8))
F1chartreg2 <- F1chartreg2 + theme(axis.title.x=element_text(size=8))
figure <- ggarrange(f0chartreg2, H1H2chartreg2, CPPchartreg2, F1chartreg2, ncol = 4, nrow = 1,common.legend = TRUE, legend = "bottom")
bmp("Fig 10 tradeoff.bmp", units="cm", width=15, height=6, res=600)
figure
dev.off()



##### INDIVIDUAL DIFFERENCES
## Based on a script written by Ta Thanh Tan in May 2019
## Reshaped by Marc Brunelle in October 2019

## This part of the script calculates Cohen's d values, based on
## - Differences between register means for 4 cues (f0, H1*-H2*, F1, F2, VOT)
## - Corresponding standard deviations
## Weigthing by register is essential as registers are not balanced, weighting by vowel is crucial for F1 and F2 


# Load additional libraries
library(Hmisc)
require(corrplot)
library(reshape)

# Get values at first measurement point after unaspirated stops
reg <- droplevels(subset(PSop, corr_t == 1 & Manner == "stop"))

# Get means
regdiff <- ddply(reg, c("Subject", "Register", "Vowel", "Age", "Sex"), summarise, 
meanf0 = mean(f0, na.rm=TRUE), 
meanH1H2 = mean(H1H2c, na.rm=TRUE), 
meanCPP = mean(CPP, na.rm=TRUE),
meanF1 = mean(F1, na.rm=TRUE), 
meanF2 = mean(F2, na.rm=TRUE), 
meanVOT = mean(VOT, na.rm=TRUE))

# Get differences between means
regdiff <- gather(regdiff, Properties, values, 6:11)
regdiff <- spread(regdiff, Register, values)
regdiff$Differences <- regdiff$High - regdiff$Low

# Get vowel- and subject- weigthed mean differences
regdiff <- ddply(regdiff, c("Subject", "Properties", "Age", "Sex"), summarise, wDiff = mean(Differences, na.rm=TRUE))

# Get register weighted standard deviations
regsd <- ddply(reg, c("Subject", "Register", "Vowel", "Age", "Sex"), summarise, 
sdf0 = sd(f0, na.rm=TRUE), 
sdH1H2 = sd(H1H2c, na.rm=TRUE),
sdCPP = sd(CPP, na.rm=TRUE),  
sdF1 = sd(F1, na.rm=TRUE), 
sdF2 = sd(F2, na.rm=TRUE), 
sdVOT = sd(VOT, na.rm=TRUE))

# Get vowel and subject weigthed standard deviation
regsd <- gather(regsd, Properties, values, 6:11)
regsd <- ddply(regsd, c("Subject", "Properties", "Age", "Sex"), summarise, wsd = mean(values, na.rm=TRUE))

# Cohen d's
regdiff$Cohend <- regdiff$wDiff / regsd$wsd  
regdiff$AgeSex <- paste0(as.character(regdiff$Sex),"", as.character(regdiff$Age))
regdiff[regdiff$Subject == "F7",]$AgeSex <- "F18'"
regdiff[regdiff$Subject == "F15",]$AgeSex <- "F33'"
regdiff[regdiff$Subject == "F5",]$AgeSex <- "F44'"
regdiff[regdiff$Subject == "M8",]$AgeSex <- "M24'"
regdiff$Properties <- revalue(regdiff$Properties, c("meanf0"="f0", "meanF1"="F1", "meanF2"="F2", "meanH1H2"="H1*-H2*", "meanVOT"="VOT", "meanCPP"="CPP"))

#Reverse H1*-H2* and F2 as they have higher values in the low register, contrary to other properties
RevCohen <- function(Properties, Cohend) {
  if(Properties == "H1*-H2*") return(Cohend*-1)
  if(Properties == "F2") return(Cohend*-1)
  else Cohend
}
regdiff$Cohend <- (mapply(RevCohen, regdiff$Properties, regdiff$Cohend))

## Plot Cohen d's (Figure 11)
regdiff$Properties <- as.factor(regdiff$Properties)
regdiff$Properties = factor(regdiff$Properties,levels(regdiff$Properties)[c(2,3,4,5,6,1)])
p <- ggplot(regdiff, aes(x = AgeSex, y=Cohend))
p <- p + geom_point(aes(colour=Properties, shape=Properties), size=3)
p <- p + labs(y = "Cohen's d", x = "Participant")
p <- p + theme(axis.text.x = element_text(size=8, angle = 90, hjust=1))
p <- p + scale_shape_manual(values=c(1,16,17,18,15,8))
p <- p + geom_hline(yintercept = 0)

#Basic acoustic properties of register (width 10cm, height 10cm)
bmp("Fig 11 IndDiff.bmp", units="cm", width=15, height=6, res=600)
p
dev.off()

