##This script 
## - loads the Chru identification data
## - merges data from different speakers 
## - add sociolinguistic and phonological variables
## - plots results
## - runs logistic regressions
## - calculate Cohen d for vowels a and u in production data
## - plot preception-production chart

## Written by James Kirby and Marc Brunelle from 2019 to 2020


##Load libraries and set working directory
require(ggplot2)
require(plyr)
require(lme4)
require(optimx)
require(rpart)
library(rpart.plot)
library(rattle)
require(gridExtra)
require(corrplot)
library(reshape2)
library(Hmisc)
library(tidyr)

theme_set(theme_bw())

## Location of the identification result .csv files
setwd("C:\\Users\\Owner\\Desktop\\Chru_paper\\Chru_paper_April_2020\\Data\\Identification_results")


##### PART I: LOAD DATA, MERGE DATA FROM DIFFERENT SPEAKERS AND ADD SOCIOLINGUISTIC AND PHONOLOGICAL VARIABLES

## load data
psfilelist = list.files(pattern = "csv$")
psdatalist = lapply(psfilelist, FUN=read.csv, header=TRUE, row.names=NULL)
df = do.call("rbind", psdatalist)

## Keep experimental blocks only
df <- droplevels(subset(df, practice == "no"))
df <- droplevels(subset(df, response != "None"))

## Too much useless data in result files. Extract relevant columns instead of deleting 
CP <- df
CP <- CP[ , 'experiment_file', drop = FALSE]
CP$Subj <- df$subject_nr
CP$F1 <- df$F1
CP$f0 <- df$f0
CP$VQ <- df$VQ
CP$VOT <- df$VOT
CP$syll <- df$syll
CP$resp <- df$response 
CP$RT <- df$response_time
CP$resp.num <- as.numeric(CP$resp)
CP$resp.num <- CP$resp.num - 1

## Convert character columns to factors 
CP$F1 <- as.factor(CP$F1)
CP$f0 <- as.factor(CP$f0)
CP$VQ <- as.factor(CP$VQ)
CP$Subj <- as.factor(CP$Subj)

## Add sex
CP$Sex <- "F"
CP[CP$Subj%in%c("12", "14", "19", "20", "22", "23", "25", "29", "30", "31", "34", "35", "36", "37", "38", "39", "40", "41", "43"),]$Sex <- "M"
CP$Sex <- as.factor(CP$Sex)

## Add year of birth
CP$YOB <- ""
CP[CP$Subj%in%c("2","14"),]$YOB <- "1973"
CP[CP$Subj == "3",]$YOB <- "1960"
CP[CP$Subj%in%c("4","12","32"),]$YOB <- "1958"
CP[CP$Subj%in%c("5","11"),]$YOB <- "2000"
CP[CP$Subj == "6",]$YOB <- "1992"
CP[CP$Subj == "7",]$YOB <- "1964"
CP[CP$Subj%in%c("8","34"),]$YOB <- "1983"
CP[CP$Subj == "9",]$YOB <- "1965"
CP[CP$Subj == "10",]$YOB <- "1982"
CP[CP$Subj == "13",]$YOB <- "1998"
CP[CP$Subj == "15",]$YOB <- "1990"
CP[CP$Subj == "16",]$YOB <- "1993"
CP[CP$Subj == "17",]$YOB <- "2001"
CP[CP$Subj == "18",]$YOB <- "1968"
CP[CP$Subj%in%c("19","36"),]$YOB <- "1987"
CP[CP$Subj%in%c("20","25"),]$YOB <- "1996"
CP[CP$Subj%in%c("21","28","40"),]$YOB <- "1991"
CP[CP$Subj == "22",]$YOB <- "1986"
CP[CP$Subj == "23",]$YOB <- "1969"
CP[CP$Subj == "24",]$YOB <- "1953"
CP[CP$Subj == "26",]$YOB <- "1974"
CP[CP$Subj == "29",]$YOB <- "1955"
CP[CP$Subj == "30",]$YOB <- "1951"
CP[CP$Subj == "32",]$YOB <- "1984"
CP[CP$Subj == "33",]$YOB <- "1966"
CP[CP$Subj == "35",]$YOB <- "1970"
CP[CP$Subj == "37",]$YOB <- "1967"
CP[CP$Subj == "38",]$YOB <- "1965"
CP[CP$Subj == "39",]$YOB <- "1976"
CP[CP$Subj == "41",]$YOB <- "1950"
CP[CP$Subj == "42",]$YOB <- "1959"
CP[CP$Subj == "43",]$YOB <- "1979"

## If listeners were also speakers in the production experiment, add their speaker ID.
CP$IDinProd <- "None"
CP[CP$Subj == "2",]$IDinProd <- "F5"
CP[CP$Subj == "3",]$IDinProd <- "F1"
CP[CP$Subj == "4",]$IDinProd <- "F4"
CP[CP$Subj == "5",]$IDinProd <- "F7"
CP[CP$Subj == "6",]$IDinProd <- "F8"
CP[CP$Subj == "9",]$IDinProd <- "F3"
CP[CP$Subj == "10",]$IDinProd <- "F15"
CP[CP$Subj == "11",]$IDinProd <- "F14"
CP[CP$Subj == "12",]$IDinProd <- "M7"
CP[CP$Subj == "13",]$IDinProd <- "F13"
CP[CP$Subj == "18",]$IDinProd <- "F6"
CP[CP$Subj == "19",]$IDinProd <- "M6"
CP[CP$Subj == "20",]$IDinProd <- "M9"
CP[CP$Subj == "23",]$IDinProd <- "M10"
CP[CP$Subj == "26",]$IDinProd <- "M2"
CP[CP$Subj == "29",]$IDinProd <- "M1"
CP[CP$Subj == "30",]$IDinProd <- "M5"
CP[CP$Subj == "33",]$IDinProd <- "F11"
CP[CP$Subj == "37",]$IDinProd <- "M4"
CP$IDinProd <- as.factor(CP$IDinProd)

agg = ddply(CP, .(syll, F1, f0, VQ, VOT), summarise, pct.s = mean(resp.num), pct.l = 1-mean(resp.num))

## Create and save identification result files
taID <-  ggplot(subset(agg, syll == "ta"), aes(VOT,pct.s,colour=F1)) + geom_line(aes(group=F1)) + geom_point(aes(group=F1, shape = F1)) + facet_grid(f0 ~ VQ) + xlab("VOT (ms)") + ylab("prop. of /t/ response") + ylim(0,1) + scale_color_discrete(name="F1 (Hz)") + scale_shape_discrete(name="F1 (Hz)") + theme(axis.title.x = element_text(vjust=-0.2))
tuqID <- ggplot(subset(agg, syll == "tuq"), aes(VOT,pct.l,colour=F1)) + geom_line(aes(group=F1)) + geom_point(aes(group=F1, shape = F1)) + facet_grid(f0 ~ VQ) + xlab("VOT (ms)") + ylab("prop. of /t/ response") + ylim(0,1) + scale_color_discrete(name="F1 (Hz)") + scale_shape_discrete(name="F1 (Hz)") + theme(axis.title.x = element_text(vjust=-0.2))

bmp("Fig 14a TaID.bmp", units="cm", width=10, height=10, res=600)
taID
dev.off()

bmp("Fig 14b TuqID.bmp", units="cm", width=10, height=10, res=600)
tuqID
dev.off()



#####	PART II: BINARY LOGISTIC REGRESSIONS (Tables 4 and 5)

CPta <- droplevels(subset(CP, syll=="ta"))
CPta$resp <- revalue(CPta$resp, c("s"="high", "l"="low"))

# Set reference as low register: the models will predict the probability of getting the high register
CPta$resp <- relevel(CPta$resp, ref="low")

# Convert factors into gradient scales (don't touch VOT as it is not a gradient) 
CPta$F1 <- as.numeric(as.factor(as.numeric(CPta$F1)))
CPta$f0 <- as.numeric(as.factor(as.numeric(CPta$f0)))
CPta$VQ <- as.numeric(as.factor(as.numeric(CPta$VQ)))

# Center variables so that 0 is the reference in the logistic regressions
CPta$F1 <- CPta$F1 - 2
CPta$f0 <- CPta$f0 - 2
CPta$VQ <- CPta$VQ - 2

# Run binary logistic regressions (Table 4)
Ida.lm <- glmer(resp~F1*f0+F1*VQ+F1*VOT+f0*VQ+f0*VOT+VQ*VOT+(1+F1|Subj)+(1+f0|Subj)+(1+VQ|Subj)+(1+VOT|Subj),CPta, family = binomial, control = glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))
# Model simplication based on F-value in anova() and t-/p- values in summary()
Ida.lm2 <- glmer(resp~F1*f0+F1*VQ+F1*VOT+f0*VQ+f0*VOT+(1+F1|Subj)+(1+f0|Subj)+(1+VQ|Subj)+(1+VOT|Subj),CPta, family = binomial, control = glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))
Ida.lm3 <- glmer(resp~F1*f0+F1*VQ+F1*VOT+f0*VQ+(1+F1|Subj)+(1+f0|Subj)+(1+VQ|Subj)+(1+VOT|Subj),CPta, family = binomial, control = glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))
##Stop here as dropping addtional interactions makes AIC worse

# Save models if desired
# save(Ida.lm3, file = "mtafinalblr.Rdata")
# write.csv(summary(Ida.lm3)$coefficients, "Table 4 mtafinalmodel.csv")


CPtuq <- droplevels(subset(CP, syll=="tuq")) 
CPtuq$resp <- revalue(CPtuq$resp, c("l"="high", "s"="low"))

# Set reference as low register: the models will predict the probability of getting the high register
CPtuq$resp <- relevel(CPtuq$resp, ref="low")

# Convert factors into gradient scales (don't touch VOT as it is not a gradient) 
CPtuq$F1 <- as.numeric(as.factor(as.numeric(CPtuq$F1)))
CPtuq$f0 <- as.numeric(as.factor(as.numeric(CPtuq$f0)))
CPtuq$VQ <- as.numeric(as.factor(as.numeric(CPtuq$VQ)))

# Center variables so that 0 is the reference in the logistic regressions
CPtuq$F1 <- CPtuq$F1 - 2
CPtuq$f0 <- CPtuq$f0 - 2
CPtuq$VQ <- CPtuq$VQ - 2

# Run binary logistic regressions (Table 5)
Iduq.lm <- glmer(resp~F1*f0+F1*VQ+F1*VOT+f0*VQ+f0*VOT+VQ*VOT+(1+F1|Subj)+(1+f0|Subj)+(1+VQ|Subj)+(1+VOT|Subj),CPtuq, family = binomial, glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))
Iduq.lm2 <- glmer(resp~F1*VQ+F1*VOT+f0*VQ+f0*VOT+VQ*VOT+(1+F1|Subj)+(1+f0|Subj)+(1+VQ|Subj)+(1+VOT|Subj),CPtuq, family = binomial, glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))
Iduq.lm3 <- glmer(resp~F1*VOT+f0*VQ+f0*VOT+VQ*VOT+(1+F1|Subj)+(1+f0|Subj)+(1+VQ|Subj)+(1+VOT|Subj),CPtuq, family = binomial, glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))
Iduq.lm4 <- glmer(resp~F1*VOT+f0*VOT+VQ*VOT+(1+F1|Subj)+(1+f0|Subj)+(1+VQ|Subj)+(1+VOT|Subj),CPtuq, family = binomial, glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))
Iduq.lm5 <- glmer(resp~F1*VOT+f0*VOT+VQ+(1+F1|Subj)+(1+f0|Subj)+(1+VQ|Subj)+(1+VOT|Subj),CPtuq, family = binomial, glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))
Iduq.lm6 <- glmer(resp~F1*VOT+f0+VQ+(1+F1|Subj)+(1+f0|Subj)+(1+VQ|Subj)+(1+VOT|Subj),CPtuq, family = binomial, glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))
##Stop here as dropping VQ makes AIC worse

# Save models if desired
# save(Iduq.lm6, file = "tuqfinalblr.Rdata")
# write.csv(summary(Iduq.lm6)$coefficients, "Table 5 tuqfinalmodel.csv")


##### PART 3: MATCH BETWEEN PRODUCTION AND PERCEPTION
## COMPARE COHEN D'S AND LOGISTIC REGRESSIONS

## Load results of acoustic experiments
setwd("C:\\Users\\Owner\\Desktop\\Chru_paper\\Chru_paper_April_2020\\Data\\Acoustic_results")
PSop <- read.csv("PSopfinal.csv")

## Calculate Cohen d's for vowel a after stops

rega <- droplevels(subset(PSop, corr_t == 1 & Manner == "stop" & Vowel == "a"))

# Get means and mean differences
regadiff <- ddply(rega, c("Subject", "Register", "Vowel", "Age", "Sex"), summarise, 
meanf0 = mean(f0, na.rm=TRUE), 
meanH1H2 = mean(H1H2c, na.rm=TRUE), 
meanF1 = mean(F1, na.rm=TRUE), 
meanF2 = mean(F2, na.rm=TRUE), 
meanVOT = mean(VOT, na.rm=TRUE))

regadiff <- gather(regadiff, Properties, values, 6:10)
regadiff <- spread(regadiff, Register, values)
regadiff$Differences <- regadiff$High - regadiff$Low

# Get vowel and subject weigthed mean differences
regadiff <- ddply(regadiff, c("Subject", "Properties", "Age", "Sex"), summarise, wDiff = mean(Differences, na.rm=TRUE))

# Now get register weighted standard deviations
regasd <- ddply(rega, c("Subject", "Register", "Vowel", "Age", "Sex"), summarise, 
sdf0 = sd(f0, na.rm=TRUE), 
sdH1H2 = sd(H1H2c, na.rm=TRUE), 
sdF1 = sd(F1, na.rm=TRUE), 
sdF2 = sd(F2, na.rm=TRUE), 
sdVOT = sd(VOT, na.rm=TRUE))

regasd <- gather(regasd, Properties, values, 6:10)

# Get vowel and subject weigthed standard deviation
regasd <- ddply(regasd, c("Subject", "Properties", "Age", "Sex"), summarise, wsd = mean(values, na.rm=TRUE))

# Cohen's d
regadiff$Cohend <- abs(regadiff$wDiff / regasd$wsd)  
regadiff$AgeSex <- paste0(as.character(regadiff$Sex),"", as.character(regadiff$Age))
regadiff$Properties <- revalue(regadiff$Properties, c("meanf0"="f0", "meanF1"="F1", "meanF2"="F2", "meanH1H2"="H1*-H2*", "meanVOT"="VOT"))

##Data set for correlations
regadiff[5] <- NULL
regaCohen <- spread(regadiff, c("Properties"), Cohend)
colnames(regaCohen)[colnames(regaCohen)=="H1*-H2*"] <- "H1H2"

## Calculate Cohen d's for vowel u after stops

regu <- droplevels(subset(PSop, corr_t == 1 & Manner == "stop" & Vowel == "u"))

# Get means and mean differences
regudiff <- ddply(regu, c("Subject", "Register", "Vowel", "Age", "Sex"), summarise, 
meanf0 = mean(f0, na.rm=TRUE), 
meanH1H2 = mean(H1H2c, na.rm=TRUE), 
meanF1 = mean(F1, na.rm=TRUE), 
meanF2 = mean(F2, na.rm=TRUE), 
meanVOT = mean(VOT, na.rm=TRUE))

regudiff <- gather(regudiff, Properties, values, 6:10)
regudiff <- spread(regudiff, Register, values)
regudiff$Differences <- regudiff$High - regudiff$Low

# Get vowel and subject weigthed mean differences
regudiff <- ddply(regudiff, c("Subject", "Properties", "Age", "Sex"), summarise, wDiff = mean(Differences, na.rm=TRUE))

# Now get register weighted standard deviations
regusd <- ddply(regu, c("Subject", "Register", "Vowel", "Age", "Sex"), summarise, 
sdf0 = sd(f0, na.rm=TRUE), 
sdH1H2 = sd(H1H2c, na.rm=TRUE), 
sdF1 = sd(F1, na.rm=TRUE), 
sdF2 = sd(F2, na.rm=TRUE), 
sdVOT = sd(VOT, na.rm=TRUE))

regusd <- gather(regusd, Properties, values, 6:10)

# Get vowel and subject weigthed standard deviation
regusd <- ddply(regusd, c("Subject", "Properties", "Age", "Sex"), summarise, wsd = mean(values, na.rm=TRUE))

# Cohen's d
regudiff$Cohend <- abs(regudiff$wDiff / regusd$wsd)  
regudiff$AgeSex <- paste0(as.character(regudiff$Sex),"", as.character(regudiff$Age))
regudiff$Properties <- revalue(regudiff$Properties, c("meanf0"="f0", "meanF1"="F1", "meanF2"="F2", "meanH1H2"="H1*-H2*", "meanVOT"="VOT"))

##Data set for correlations
regudiff[5] <- NULL
reguCohen <- spread(regudiff, c("Properties"), Cohend)
colnames(reguCohen)[colnames(reguCohen)=="H1*-H2*"] <- "H1H2"

## Get individual logistic regression for mta
CPta <- droplevels(subset(CP, syll=="ta"))

# Rescale numerical factors (in a weird way, but it works)
CPta$resp <- revalue(CPta$resp, c("s"="high", "l"="low"))
CPta$resp <- relevel(CPta$resp, ref="low")
CPta$VOT <- relevel(CPta$VOT, ref="neg")
#Reference is low, so the models will predict the probability of getting the high register
# Convert factors into gradient scales (don't touch VOT as it is not a gradient) 
CPta$F1 <- as.numeric(as.factor(as.numeric(CPta$F1)))
CPta$f0 <- as.numeric(as.factor(as.numeric(CPta$f0)))
CPta$VQ <- as.numeric(as.factor(as.numeric(CPta$VQ)))
CPta$VOT <- as.numeric(as.factor(as.numeric(CPta$VOT)))
# Center variables
CPta$F1 <- CPta$F1 - 2
CPta$f0 <- CPta$f0 - 2
CPta$VQ <- CPta$VQ - 2

Lista <- levels(CPta$Subj)
ListCoefMata <- matrix(nrow=length(Lista), ncol=5)
colnames(ListCoefMata) <- c("Subj", "VOTperc", "F1perc", "f0perc", "VQperc")

# Here, adjust the p-value and decide if 0 or NA gets reported for values above p
for(i in 1:length(Lista)){
	Listsuba <- droplevels(subset(CPta, Subj == Lista[i]))
	Listmoda <- glm(resp~VOT+F1+f0+VQ,Listsuba, family = binomial(link = "logit"))	
	ListCoefMata[i,1] <- Lista[i]
	if(coef(summary(Listmoda))[2,4] < 1){
		ListCoefMata[i,2] <- coef(Listmoda)["VOT"]}else{NA}	
	if(coef(summary(Listmoda))[3,4] < 1){
		ListCoefMata[i,3] <- coef(Listmoda)["F1"]}else{NA}
	if(coef(summary(Listmoda))[4,4] < 1){
		ListCoefMata[i,4] <- coef(Listmoda)["f0"]}else{NA}	
	if(coef(summary(Listmoda))[5,4] < 1){
		ListCoefMata[i,5] <- coef(Listmoda)["VQ"]}else{NA}	
}

Listdfta <- as.data.frame(ListCoefMata)
 
# Use the same participant IDs as in the acoustic experiment
Listdfta$IDinProd <- "None"
Listdfta[Listdfta$Subj == "2",]$IDinProd <- "F5"
Listdfta[Listdfta$Subj == "3",]$IDinProd <- "F1"
Listdfta[Listdfta$Subj == "4",]$IDinProd <- "F4"
Listdfta[Listdfta$Subj == "5",]$IDinProd <- "F7"
Listdfta[Listdfta$Subj == "6",]$IDinProd <- "F8"
Listdfta[Listdfta$Subj == "9",]$IDinProd <- "F3"
Listdfta[Listdfta$Subj == "10",]$IDinProd <- "F15"
Listdfta[Listdfta$Subj == "11",]$IDinProd <- "F14"
Listdfta[Listdfta$Subj == "12",]$IDinProd <- "M7"
Listdfta[Listdfta$Subj == "13",]$IDinProd <- "F13"
Listdfta[Listdfta$Subj == "18",]$IDinProd <- "F6"
Listdfta[Listdfta$Subj == "19",]$IDinProd <- "M6"
Listdfta[Listdfta$Subj == "20",]$IDinProd <- "M9"
Listdfta[Listdfta$Subj == "23",]$IDinProd <- "M10"
Listdfta[Listdfta$Subj == "26",]$IDinProd <- "M2"
Listdfta[Listdfta$Subj == "29",]$IDinProd <- "M1"
Listdfta[Listdfta$Subj == "30",]$IDinProd <- "M5"
Listdfta[Listdfta$Subj == "33",]$IDinProd <- "F11"
Listdfta[Listdfta$Subj == "37",]$IDinProd <- "M4"
Listdfta$IDinProd <- as.factor(Listdfta$IDinProd)
Listdfta <- as.data.frame(Listdfta)

Listdfta$f0perc <- as.character(Listdfta$f0perc)
Listdfta$F1perc <- as.character(Listdfta$F1perc)
Listdfta$VQperc <- as.character(Listdfta$VQperc)
Listdfta$VOTperc <- as.character(Listdfta$VOTperc)
Listdfta[is.na(Listdfta)] <- 0
Listdfta$f0perc <- abs(as.numeric(Listdfta$f0perc))
Listdfta$F1perc <- abs(as.numeric(Listdfta$F1perc))
Listdfta$VQperc <- abs(as.numeric(Listdfta$VQperc))
Listdfta$VOTperc <- abs(as.numeric(Listdfta$VOTperc))

IDProda <- merge(regaCohen, Listdfta, by.x = "Subject", by.y ="IDinProd")

# Plot of correlation between Cohen d's and Estimates of logistic regressions for mta
pa <- ggplot(IDProda)
pa <- pa + geom_point(aes(x=f0, y=f0perc, shape="f0", color="f0"))  
pa <- pa + geom_point(aes(x=F1, y=F1perc, shape="F1", color="F1"))  
pa <- pa + geom_point(aes(x=VOT, y=VOTperc, shape="VOT", color="VOT"))
pa <- pa + geom_point(aes(x=H1H2, y=VQperc, shape="VQ", color="VQ"))   
pa <- pa + scale_color_discrete(name="Properties", breaks=c("f0","F1", "VQ", "VOT"), labels=c("f0","F1", "VQ", "VOT")) + scale_shape_discrete(name="Properties", breaks=c("f0","F1", "VQ", "VOT"), labels=c("f0","F1", "VQ", "VOT"))
pa <- pa + scale_shape_manual(name = "Properties", values=c(1,16,15,18)) + scale_color_manual(name = "Properties", values=c("#F8766D","#A3A500","dodgerblue1","darkturquoise"))
pa <- pa + ggtitle("Vowel a") + theme(plot.title = element_text(face = "bold", size=10, hjust=0.5))+ xlab("Acoustic Weight (Cohen's d)") + ylab("Perceptual Weight (|\U03B2|)")
pa <- pa + xlim(0,12) + ylim(0,4)
pa


## GET INDIVIDUAL LOGISTIC REGRESSIONS FOR TUQ
CPtuq <- droplevels(subset(CP, syll=="tuq"))

# Rescale numerical factors (in a weird way, but it works)
CPtuq$resp <- revalue(CPtuq$resp, c("s"="high", "l"="low"))
CPtuq$resp <- relevel(CPtuq$resp, ref="low")
CPtuq$VOT <- relevel(CPtuq$VOT, ref="neg")
#Reference is low, so the models will predict the probability of getting the high register
# Convert factors into gradient scales (don't touch VOT as it is not a gradient) 
CPtuq$F1 <- as.numeric(as.factor(as.numeric(CPtuq$F1)))
CPtuq$f0 <- as.numeric(as.factor(as.numeric(CPtuq$f0)))
CPtuq$VQ <- as.numeric(as.factor(as.numeric(CPtuq$VQ)))
CPtuq$VOT <- as.numeric(as.factor(as.numeric(CPtuq$VOT)))
# Center variables
CPtuq$F1 <- CPtuq$F1 - 2
CPtuq$f0 <- CPtuq$f0 - 2
CPtuq$VQ <- CPtuq$VQ - 2

Listu <- levels(CPtuq$Subj)
ListCoefMatu <- matrix(nrow=length(Listu), ncol=5)
colnames(ListCoefMatu) <- c("Subj", "VOTperc", "F1perc", "f0perc", "VQperc")

for(i in 1:length(Listu)){
	Listsubu <- droplevels(subset(CPtuq, Subj == Listu[i]))
	Listmodu <- glm(resp~VOT+F1+f0+VQ,Listsubu, family = binomial(link = "logit"))	
	ListCoefMatu[i,1] <- Listu[i]
	if(coef(summary(Listmodu))[2,4] < 1){
		ListCoefMatu[i,2] <- coef(Listmodu)["VOT"]}else{NA}	
	if(coef(summary(Listmodu))[3,4] < 1){
		ListCoefMatu[i,3] <- coef(Listmodu)["F1"]}else{NA}
	if(coef(summary(Listmodu))[4,4] < 1){
		ListCoefMatu[i,4] <- coef(Listmodu)["f0"]}else{NA}	
	if(coef(summary(Listmodu))[5,4] < 1){
		ListCoefMatu[i,5] <- coef(Listmodu)["VQ"]}else{NA}	
}

Listdftuq <- as.data.frame(ListCoefMatu)

# Use the same participant IDs as in the acoustic experiment
Listdftuq$IDinProd <- "None"
Listdftuq[Listdftuq$Subj == "2",]$IDinProd <- "F5"
Listdftuq[Listdftuq$Subj == "3",]$IDinProd <- "F1"
Listdftuq[Listdftuq$Subj == "4",]$IDinProd <- "F4"
Listdftuq[Listdftuq$Subj == "5",]$IDinProd <- "F7"
Listdftuq[Listdftuq$Subj == "6",]$IDinProd <- "F8"
Listdftuq[Listdftuq$Subj == "9",]$IDinProd <- "F3"
Listdftuq[Listdftuq$Subj == "10",]$IDinProd <- "F15"
Listdftuq[Listdftuq$Subj == "11",]$IDinProd <- "F14"
Listdftuq[Listdftuq$Subj == "12",]$IDinProd <- "M7"
Listdftuq[Listdftuq$Subj == "13",]$IDinProd <- "F13"
Listdftuq[Listdftuq$Subj == "18",]$IDinProd <- "F6"
Listdftuq[Listdftuq$Subj == "19",]$IDinProd <- "M6"
Listdftuq[Listdftuq$Subj == "20",]$IDinProd <- "M9"
Listdftuq[Listdftuq$Subj == "23",]$IDinProd <- "M10"
Listdftuq[Listdftuq$Subj == "26",]$IDinProd <- "M2"
Listdftuq[Listdftuq$Subj == "29",]$IDinProd <- "M1"
Listdftuq[Listdftuq$Subj == "30",]$IDinProd <- "M5"
Listdftuq[Listdftuq$Subj == "33",]$IDinProd <- "F11"
Listdftuq[Listdftuq$Subj == "37",]$IDinProd <- "M4"
Listdftuq$IDinProd <- as.factor(Listdftuq$IDinProd)
Listdftuq <- as.data.frame(Listdftuq)

Listdftuq$f0perc <- as.character(Listdftuq$f0perc)
Listdftuq$F1perc <- as.character(Listdftuq$F1perc)
Listdftuq$VQperc <- as.character(Listdftuq$VQperc)
Listdftuq$VOTperc <- as.character(Listdftuq$VOTperc)
Listdftuq[is.na(Listdftuq)] <- 0
Listdftuq$f0perc <- abs(as.numeric(Listdftuq$f0perc))
Listdftuq$F1perc <- abs(as.numeric(Listdftuq$F1perc))
Listdftuq$VQperc <- abs(as.numeric(Listdftuq$VQperc))
Listdftuq$VOTperc <- abs(as.numeric(Listdftuq$VOTperc))

IDProdu <- merge(reguCohen, Listdftuq, by.x = "Subject", by.y ="IDinProd")

# Plot of correlation between Cohen d's and Estimates of logistic regressions for tuq
pu <- ggplot(IDProdu)
pu <- pu + geom_point(aes(x=f0, y=f0perc, shape="f0", color="f0"))  
pu <- pu + geom_point(aes(x=F1, y=F1perc, shape="F1", color="F1"))  
pu <- pu + geom_point(aes(x=VOT, y=VOTperc, shape="VOT", color="VOT")) 
pu <- pu + geom_point(aes(x=H1H2, y=VQperc, shape="VQ", color="VQ"))  
pu <- pu + scale_color_discrete(name="Properties", breaks=c("f0","F1", "VQ", "VOT"), labels=c("f0","F1", "VQ", "VOT")) + scale_shape_discrete(name="Properties", breaks=c("f0","F1", "VQ", "VOT"), labels=c("f0","F1", "VQ", "VOT"))
pu <- pu + scale_shape_manual(name = "Properties", values=c(1,16,15,18)) + scale_color_manual(name = "Properties", values=c("#F8766D","#A3A500","dodgerblue1","darkturquoise"))
pu <- pu + ggtitle("Vowel u") + theme(plot.title = element_text(face = "bold", size=10, hjust=0.5))+ xlab("Acoustic Weight (Cohen's d)") + ylab("Perceptual Weigth (|\U03B2|)")
pu <- pu + xlim(0,12) + ylim(0,4)
pu


# Create chart for perceptual and acoustic weights (Figure 15)
library(ggpubr)
setwd("C:\\Users\\Owner\\Desktop\\Chru_paper\\Chru_paper_April_2020\\Data\\Identification_results")
pupa <- ggarrange(pa, pu +  theme(axis.text.y = element_blank(),axis.ticks.y = element_blank(), axis.title.y = element_blank() ), ncol = 2, nrow = 1, common.legend=TRUE, legend="bottom")
#Basic acoustic properties of register 
bmp("Fig 15 PercProd.bmp", units="cm", width=15, height=9, res=600)
pupa
dev.off()


###Correlations between production and perception weigths (Section 3.2)

IDProdarev <- gather(IDProda, Prod, Prodval, 5:9)
IDProdarev <- gather(IDProdarev, Perc, Percval, 6:9)

IDProdurev <- gather(IDProdu, Prod, Prodval, 5:9)
IDProdurev <- gather(IDProdurev, Perc, Percval, 6:9)


corfun<-function(x, y) {
  corr=(cor.test(x, y))
}


ddply(IDProdarev, .(Prod), summarise,r=corfun(Prodval,Percval)$estimate,
      pval=corfun(Prodval,Percval)$p.value) 

ddply(IDProdurev, .(Prod), summarise,r=corfun(Prodval,Percval)$estimate,
      pval=corfun(Prodval,Percval)$p.value) 